/*****************************************************************************
* File name : MiscFunctions.C
* Purpose: Contains initialize, compare, memory fill and memory copy functions
* Author: Mitesh Moonat
* VDSP version used for testing: CCES Cygnus M2
* Hardware used: BF707 EZ-Kit
* Connection details :  N/A
 *****************************************************************************/
#include  "MiscFunctions.h"
/*************************************************************************************************************************
									Global Variables
**************************************************************************************************************************/
int iTestResult; //Contains the final test result, =0 when test failed, =1 when test passed

/*****************************************************************************************
*	Macro name:  InitBuf
*	Description:	This macro initializes the Buffer with a variable pattern. User may
*	pass buffers with byte/short/integer data types, function allocates accordingly.
*		Parameter	 		|	Description		 					| Valid values      |
*	    Datatype			|  	type of buffer						| byte/short/integer|
*		InitBuf				|  	Buffer to be initialized with data  | byte/short/integer|
*		uiSize				|	Size of buffer						| Valid memory range|
*		uiBytesPerWord      |   Data type buffer byte/short/integer	| 1 or 2 or 4       |
*		uiPattern			|	Pattern to be written 				| RAND/INCREMENT    |
*		uiMask  			|   # of bits to be written				| 0-31				|
*		uiStride			|	# of address between each pattern   | 1-uiSize			|
*   Return value:    None.
*******************************************************************************************/
#define InitBuf(DataType,InitBuf,uiSize,uiPattern,uiMask,uiStride)\
		DataType *pBuf;\
		pBuf =(DataType*)InitBuf;\
		int nIndex;\
	    for (nIndex=0; nIndex < ceil((float)(uiSize/uiStride)); nIndex++, (pBuf = pBuf + uiStride))\
	     	 {\
	     		if (uiPattern == INCREMENT)\
	     		 	 *pBuf = nIndex & ((DataType) uiMask);\
	     		else\
	     			*pBuf = rand() & ((DataType) uiMask);\
	     	 }\
/*****************************************************************************************
*	Function name:  Buf_Init
*	Description:	This function initializes the Buffer with a variable pattern. User may
*	pass buffers with byte/short/integer data types, function allocates accordingly.
*		Parameter	 		|	Description		 					| Valid values      |
*		InitBuf				|  	Buffer to be initialized with data  | byte/short/integer|
*		uiSize				|	Size of buffer						| Valid memory range|
*		uiBytesPerWord      |   Data type buffer byte/short/integer	| 1 or 2 or 4       |
*		uiPattern			|	Pattern to be written 				| RAND/INCREMENT    |
*		uiMask  			|   # of bits to be written				| 0-31				|
*		uiStride			|	# of address between each pattern   | 1-uiSize			|
*   Return value:    None.
*******************************************************************************************/

void Buf_Init(void* InitBuf, unsigned int uiSize, unsigned int uiBytesPerWord, unsigned int uiPattern,  unsigned int uiMask, unsigned int uiStride)
{

	if(uiBytesPerWord == 1)
	{
		InitBuf(char,InitBuf,uiSize,uiPattern,uiMask,uiStride);
	}
	else if(uiBytesPerWord == 2)
	{
		InitBuf(short,InitBuf,uiSize,uiPattern,uiMask,uiStride);
	}
	else if(uiBytesPerWord == 4)
	{
		InitBuf(int,InitBuf,uiSize,uiPattern,uiMask,uiStride);
	}
}

/*****************************************************************************************
*	Macro name:  Compare
*	Description:	This macro compares the two buffer values and returns based on result.
*	User may pass buffers with byte/short/integer data types, function compares accordingly.
*	    Parameter	 		|	Description		 					| Valid values      |
*	    Datatype			|  		type of buffer  				| byte/short/integer|
*		CmpBuf1				|  	Buffer to be comparing against 		| byte/short/integer|
*		CmpBuf2				|	Buffer to be compared  				| byte/short/integer|
*		uiSize				|	Size of buffer						| Valid memory range|
*		uiMask  			|   # of bits to be written				| 0-31				|
*		uiStride			|	# of address between each pattern   | 1-uiSize			|
*   Return value: Return 0 on a match. Returns Buffer1 current address where first mismatch happened.
*******************************************************************************************/

 #define   Compare(DataType, CmpBuf1, CmpBuf2, uiSize, uiMask, uiStride) \
			DataType *pBuf1, *pBuf2;\
			pBuf1 =(DataType*)CmpBuf1;\
			pBuf2 =(DataType*)CmpBuf2;\
			int nIndex;\
			for (nIndex=0; nIndex < ceil((float)(uiSize/uiStride)); nIndex++,(pBuf1 = pBuf1 + uiStride), (pBuf2 = pBuf2 + uiStride))\
				{\
					if (!((*pBuf1 & ((DataType) uiMask))  == (*pBuf2 & ((DataType) uiMask))))\
						{\
							CmpResult = (int) pBuf2;\
							return CmpResult;\
						}\
				}\
/*****************************************************************************************
*	Function name:  Buf_Compare
*	Description:	This function compares the two buffer values and returns based on result.
*	User may pass buffers with byte/short/integer data types, function compares accordingly.
*	    Parameter	 		|	Description		 					| Valid values      |
*		CmpBuf1				|  	Buffer to be comparing against 		| byte/short/integer|
*		CmpBuf2				|	Buffer to be compared  				| byte/short/integer|
*		uiSize				|	Size of buffer						| Valid memory range|
*		uiBytesPerWord      |   Data type buffer byte/short/integer	| 1 or 2 or 4       |
*		uiMask  			|   # of bits to be written				| 0-31				|
*		uiStride			|	# of address between each pattern   | 1-uiSize			|
*   Return value: Return 0 on a match. Returns Buffer1 current address where first mismatch happened.
*******************************************************************************************/
int Buf_Compare(void* CmpBuf1, void* CmpBuf2, unsigned int uiSize, unsigned int uiBytesPerWord,  unsigned int uiMask, unsigned int uiStride)
{
	int CmpResult = 0;
	if(uiBytesPerWord == 1)
		{
		Compare(char, CmpBuf1, CmpBuf2, uiSize, uiMask, uiStride);
		}
	else if(uiBytesPerWord == 2)
		{
		Compare(short, CmpBuf1, CmpBuf2, uiSize, uiMask, uiStride);
		}

	else if(uiBytesPerWord == 4)
		{
		Compare(int, CmpBuf1, CmpBuf2, uiSize, uiMask, uiStride);
		}

	return CmpResult;
}

/*****************************************************************************************
*	Macro name:  Fill
*	Description: Fills the contents of InitBuf with uiSize based on the pattern chosen.
*				 This macro is used by the Buf_Fill function.
*		Parameter	 		|	Description		 					| Valid values      |
*		Datatype			|  		type of buffer  				| byte/short/integer|
*		InitBuf				|  	Buffer to be initialized with data  | byte/short/integer|
*		uiSize				|	Size of buffer						|Valid memory range |
*		uiPattern			|	Pattern to be written 				| any pattern       |
*		uiMask  			|   # of bits to be written				| 0-31				|
*		uiStride			|	# of address between each pattern   | 1-uiSize			|
*   Return value:    None.
*******************************************************************************************/
#define  Fill(DataType,InitBuf,uiSize,uiPattern ,uiMask, uiStride)\
		 DataType *pBuf;\
		 pBuf =(DataType*)InitBuf;\
		 int nIndex;\
		 for (nIndex=0; nIndex < ceil((float)(uiSize/uiStride)); nIndex++, (pBuf = pBuf + uiStride))\
		 	 	 *pBuf = uiPattern & ((DataType) uiMask);\
/*****************************************************************************************
*	Function name:  Buf_Fill
*	Description:	This function fills the buffer with a constant pattern. User can pass
*	byte/short/integer buffer, function fills accordingly.
*		Parameter	 		|	Description		 					| Valid values      |
*		InitBuf				|  	Buffer to be initialized with data  | byte/short/integer|
*		uiSize				|	Size of buffer						|Valid memory range |
*		uiBytesPerWord      |   Data type buffer byte/short/integer	| 1 or 2 or 4       |
*		uiPattern			|	Pattern to be written 				| any pattern       |
*		uiMask  			|   # of bits to be written				| 0-31				|
*		uiStride			|	# of address between each pattern   | 1-uiSize			|
*   Return value:    None.
*******************************************************************************************/
void Buf_Fill(void* InitBuf, unsigned int uiSize, unsigned int uiBytesPerWord, unsigned int uiPattern,  unsigned int uiMask, unsigned int uiStride)
{
	if(uiBytesPerWord == 1)
	{
		Fill(char,InitBuf,uiSize,uiPattern ,uiMask, uiStride);
	}

	else if(uiBytesPerWord == 2)
	{
		Fill(short,InitBuf,uiSize,uiPattern ,uiMask, uiStride);
	}

	else if(uiBytesPerWord == 4)
	{
		Fill(int,InitBuf,uiSize,uiPattern ,uiMask, uiStride);
	}

}
/*****************************************************************************************
*	Macro name:  Cpy
*	Description: Copies the contents of SrcBuf with uiSize to DestBuf. This macro is used
*				 by the Mem_Cpy function.
*		Parameter	 		|	Description		 					| Valid values      |
*		Datatype			|  		type of buffer 					| byte/short/integer|
*		SrcBuf				|  	Copy from  this buffer			    | byte/short/integer|
*		DestBuf				|  	Copy to this buffer		            | byte/short/integer|
*		uiSize				|	Size of buffer						| Valid memory range|
*   Return value:    None.
*******************************************************************************************/
#define Cpy(DataType,SrcBuf,DestBuf,uiSize)\
            DataType *pBuf1, *pBuf2;\
		    pBuf1 =(DataType*)SrcBuf;\
			pBuf2 =(DataType*)DestBuf;\
			int nIndex;\
			for (nIndex=0; nIndex < uiSize; nIndex++, pBuf1++, pBuf2++)\
				 *pBuf2 = *pBuf1;\
/*****************************************************************************************
*	Function name:  Mem_Cpy
*	Description:	This function copies from one memory location to another. User can pass
*	byte/short/integer buffer, function fills accordingly.
*		Parameter	 		|	Description		 					| Valid values      |
*		SrcBuf				|  	Copy from  this buffer			    | byte/short/integer|
*		DestBuf				|  	Copy to this buffer		            | byte/short/integer|
*		uiSize				|	Size of buffer						| Valid memory range|
*		uiBytesPerWord      |   Data type buffer byte/short/integer	| 1 or 2 or 4       |
*   Return value:    None.
*******************************************************************************************/
void Mem_Cpy(void* SrcBuf, void* DestBuf, unsigned int uiSize,unsigned int uiBytesPerWord)
{
	if (uiBytesPerWord == 1)
	{
		Cpy(char, SrcBuf, DestBuf, uiSize);
	}
	else if (uiBytesPerWord == 2)
	{
		Cpy(short, SrcBuf, DestBuf, uiSize);
	}
	else if  (uiBytesPerWord == 4)
	{
		Cpy(int, SrcBuf, DestBuf, uiSize);
	}
}
/**************************************************************************************************************************
	Function name	:  	Indicate_Pass
    Description		:   This function provides a test pass indication by blinking an LED (defined as PASS_LED in
    					"ProcessorSpecific.h") 5 times and by setting a global variable named "iTestResult"
	Arguments		:	None
	Return value	:   None
**************************************************************************************************************************/
void Indicate_Pass(void)
{
	int i,j;

	//Blink LED connected to PG14 5 times to indicate pass
	for(j=0;j<5;j++)
	{
		CONFIGURE_PASS_LED_AS_OUTPUT();
		Delay(5000000);
		SET_PASS_LED();
		Delay(5000000);
		CLEAR_PASS_LED();
	}

	iTestResult=1;
}
/**************************************************************************************************************************
	Function name	:  	Indicate_Fail
    Description		:   This function provides a test fail indication by blinking an LED (defined as FAIL_LED in
    					"ProcessorSpecific.h") 5 times and by clearing a global variable named "iTestResult"
	Arguments		:	None
	Return value	:   None
**************************************************************************************************************************/
void Indicate_Fail(void)
{
	int i, j;
	//Blink LED connected to PG15 5 times to indicate fail
	for(j=0;j<5;j++)
	{
		CONFIGURE_FAIL_LED_AS_OUTPUT();
		Delay(5000000);
		SET_FAIL_LED();
		Delay(5000000);
		CLEAR_FAIL_LED();
	}

	iTestResult=0;
}
/**************************************************************************************************************************
	Function name	:  	Delay
    Description		:   This function produces a programmable delay
	Arguments		:	Parameter	 |	Description		 								| Valid values
						uiDelay		 |  Delay value					 					| 32 bit unsigned integer value
	Return value	:   None
**************************************************************************************************************************/
void Delay(unsigned int uiDelay)
{
	int i=0;
	for(i=0;i<uiDelay;i++);
}

/**************************************************************************************************************************
	Function name	:  	Print_Console
    Description		:   This function prints a debug text in console only if required (DEBUG_MODE)
	Arguments		:	Parameter	 |	Description		 								| Valid values
						sText		 |  test to be printed			 					| string
	Return value	:   None
**************************************************************************************************************************/
void Print_Console(char* sText)
{
	#ifdef DEBUG_MODE
			printf("\n%s\n",sText);
	#endif
}
