/*
  Oscillator Comparator Unit
  ADSP-CM419 
  
*/
#include "OCU_Init.h"
#include "CGUInit.h"
#include "device.h"

void OCU_Init(unsigned int ref_cnt, unsigned short int clk_ppm, unsigned short int lfo_ppm)
{
  unsigned int sysclk = 0;
  unsigned int sysclk_cnt = 0;
  unsigned int ocu_clk = LFO_CM41x / 16;
  
  while((*pREG_OCU0_STAT & BITM_OCU_STAT_BUSY));
  *pREG_OCU0_CTL &= 0xFFFFFFFC;  // Clear Measure and Auto bit
  
  //Get SYS_CLK from CGU
   unsigned short int msel = (*pREG_CGU0_CTL & BITM_CGU_CTL_MSEL) >> BITP_CGU_CTL_MSEL;
   unsigned short int syssel = (*pREG_CGU0_DIV & BITM_CGU_DIV_SYSSEL) >> BITP_CGU_DIV_SYSSEL;
   unsigned short int df = (*pREG_CGU0_CTL & BITM_CGU_CTL_DF) >> BITP_CGU_CTL_DF;
   sysclk = ((CLKIN_CM41x / (df + 1)) * msel) / syssel;
  
  *pREG_OCU0_REFCNT = ref_cnt;
  
  // Calculate expected SYSCLK count in OCU_CLKCNT  
  sysclk_cnt = (ref_cnt / ocu_clk) * sysclk;        
  *pREG_OCU0_MINCNT = (sysclk_cnt * (1 - (clk_ppm*0.000001)) * (1 - (lfo_ppm*0.000001)) - 2);
  *pREG_OCU0_MAXCNT = (sysclk_cnt * (1 + (clk_ppm*0.000001)) * (1 + (lfo_ppm*0.000001)) + 2);
}

void OCU_Start_Manual()
{
  while((*pREG_OCU0_STAT & BITM_OCU_STAT_BUSY));
  *pREG_OCU0_CTL &= 0xFFFFFFFC;   // Clear Measure and Auto bit
  *pREG_OCU0_CTL |= BITM_OCU_CTL_MEASURE;  // Start OCU in Manual Mode  
}

void OCU_Start_Auto()
{
  while((*pREG_OCU0_STAT & BITM_OCU_STAT_BUSY));
  *pREG_OCU0_CTL &= 0xFFFFFFFC;  // Clear Measure and Auto bit
  *pREG_OCU0_CTL |= BITM_OCU_CTL_AUTO_EN;
}

void OCU_Disable_Auto()
{
  while((*pREG_OCU0_STAT & BITM_OCU_STAT_BUSY));
  *pREG_OCU0_CTL &= 0xFFFFFFFD;  // Clear Auto bit
}

void OCU_Stop_Auto()
{
   while((*pREG_OCU0_STAT & BITM_OCU_STAT_BUSY));
   *pREG_OCU0_CTL &= 0xFFFFFFFC; // Clear Measure and Auto bit
}

void OCU_Disable()
{
  while((*pREG_OCU0_STAT & BITM_OCU_STAT_BUSY));
  *pREG_OCU0_CTL = 0; // Clear Measure and Auto bit
}

void OCU_Enable_Fault(type_OCU_Fault_Type fault_type)
{
  switch (fault_type)
  {
  case FREQ_FAULT:
    *pREG_OCU0_CTL |= BITM_OCU_CTL_FREQ_FAULT_EN;
  case CMON_FAULT:
    *pREG_OCU0_CTL |= BITM_OCU_CTL_CMON_FAULT_EN;
  case LMON_FAULT:
    *pREG_OCU0_CTL |= BITM_OCU_CTL_LMON_FAULT_EN;
  case DEAD_CLK:
    *pREG_OCU0_CTL |= BITM_OCU_CTL_DEAD_CLOCK_EN;
  } 
}



