/*
  Voltage Monitoring Unit
  ADSP-CM419 
  
*/
#include "device.h"
#include "VMU_Init.h"

//---------VMU Initialization function--------//
void VMU_Init(bool vdd_int_en,
              bool vdd_ext_en,
              bool fast_comp_en,
              unsigned short int vdd_int_ref,
              unsigned short int vdd_ext_ref,
              unsigned short int fault_delay
              )
{  
  *pREG_TEPADS1_VMU_CTL = 0x00;  // Reset VMU
  
  if(vdd_int_en)
    *pREG_TEPADS1_VMU_CTL |= BITM_TEPADS_VMU_CTL_IVDDCOMPEN;  // Enable VMU VDDINT Monitoring
    *pREG_TEPADS1_VMU_CTL |= ((vdd_int_ref << BITP_TEPADS_VMU_CTL_REFPRG) & BITM_TEPADS_VMU_CTL_REFPRG);  // VDDINT reference value
  if(vdd_ext_en)    
    *pREG_TEPADS1_VMU_CTL |= BITM_TEPADS_VMU_CTL_EVDDCOMPEN;  // Enable VMU VDDEXT Monitoring
    *pREG_TEPADS1_VMU_CTL |= (((vdd_ext_ref) << BITP_TEPADS_VMU_CTL_REFPRG) & BITM_TEPADS_VMU_CTL_REFPRG);   // VDDEXT reference value
  if(fast_comp_en)
    *pREG_TEPADS1_VMU_CTL |= BITM_TEPADS_VMU_CTL_FCEN;  // Enable VDDINT fast comparator
  
  *pREG_TEPADS1_VMU_CTL |= ((fault_delay << BITP_TEPADS_VMU_CTL_FAULTDLY) & BITM_TEPADS_VMU_CTL_FAULTDLY);
  
  *pREG_TEPADS1_VMU_CTL |= BITM_TEPADS_VMU_CTL_EN;  // Enable VMU 
  for(int i=0; i<1000; ++i);    //Wait for VMU to activate
}


//---------VMU Initialization default function--------//
void VMU_Init_Default()
{
  VMU_Init(1, 1, 1, 0, 0, 10);
}

void VMU_Reset(void)
{
  *pREG_TEPADS1_VMU_CTL = 0x00;
}
