/*!
 *****************************************************************************
 * @file:    device.h
 * @brief:   CMSIS Cortex-M0 Core Peripheral Access Layer Header File for
 *           ADI ADSP-CM41x Device Series
 * @version: $Revision: 31024 $
 * @date:    $Date: 2015-05-12 12:02:06 -0400 (Tue, 12 May 2015) $
 *-----------------------------------------------------------------------------
 *
Copyright (c) 2010 Analog Devices, Inc.

All rights reserved.

Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:
  - Redistributions of source code must retain the above copyright notice,
    this list of conditions and the following disclaimer.
  - Redistributions in binary form must reproduce the above copyright notice,
    this list of conditions and the following disclaimer in the documentation
    and/or other materials provided with the distribution.
  - Modified versions of the software must be conspicuously marked as such.
  - This software is licensed solely and exclusively for use with processors
    manufactured by or for Analog Devices, Inc.
  - This software may not be combined or merged with other code in any manner
    that would cause the software to become subject to terms and conditions
    which differ from those listed here.
  - Neither the name of Analog Devices, Inc. nor the names of its
    contributors may be used to endorse or promote products derived
    from this software without specific prior written permission.
  - The use of this software may or may not infringe the patent rights of one
    or more patent holders.  This license does not release you from the
    requirement that you obtain separate licenses from these patent holders
    to use this software.

THIS SOFTWARE IS PROVIDED BY ANALOG DEVICES, INC. AND CONTRIBUTORS "AS IS" AND ANY
EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, NON-INFRINGEMENT,
TITLE, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN
NO EVENT SHALL ANALOG DEVICES, INC. OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, PUNITIVE OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, DAMAGES ARISING OUT OF CLAIMS OF INTELLECTUAL
PROPERTY RIGHTS INFRINGEMENT; PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 *****************************************************************************/

/*!  \addtogroup MMR_Layout MMR/ISR Mappings
 *  @{
 */

#ifndef __DEVICE_H__
#define __DEVICE_H__

// verify presence of a supported compiler (Keil or IAR at this time)
#if !defined(__ICCARM__) && !defined(__CC_ARM)
#error "No supported compiler found, please install one of the minimim required compilers."
#endif

// verify minimum required IAR compiler
#ifdef __ICCARM__
#define MIN_CC_VERSION 6010001  // known value for release 6.10.1
#if (MIN_CC_VERSION > __VER__)
#error "Unsupported compiler version, please install minimum required compiler version."
#endif
#endif

// verify minimum required Keil compiler
#ifdef __CC_ARM
#define MIN_CC_VERSION 410713  // known value for release 4.21
#if (MIN_CC_VERSION > __ARMCC_VERSION)
#error "Unsupported compiler version, please install minimum required compiler version."
#endif
#endif

/* Feature macro for conditional compilation */
#define ADI_ADSP_CM41X          /*!< Generic PreProcessor feature macro */
#define ADI_ADSP_CM41X_M0       /*!< M0-Specific PreProcessor feature macro */

/* include global MISRA suppressions */
//#include "misra.h"

/* pickup register bitfield and bit mask macros */
//#include "macros.h"

/* pickup system interrupt ID (SID) defines */
#include <services/int/adi_sid_cm41x_m0.h>

/* pickup NVIC SID Mappings and interrup hooking prototypes */
#include "adi_nvic.h"

/* C++ linkage */
#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

/* The below code segment is required to disable the interrupt at the NVIC level.
 * If the program is already running from Flash the interrupt gets invoked as soon
 * as we install the handler. Below code acknowledges any pending interrupts at the
 * NVIC level.
 */
#if defined(ADI_ADSP_CM41X)
#define ADI_ACK_PENDINT(irq)       \
    do {                           \
    if (NVIC_GetPendingIRQ(irq))   \
    {                              \
        NVIC_ClearPendingIRQ(irq); \
    }                              \
    }while(0)
#else
#define ADI_ACK_PENDINT(irq)
#endif

/*  =========================================================================
 *! \enum   IRQn_Type
 *! \brief  Interrupt Number Assignments
 *  ========================================================================= */
typedef enum
{
	RESET_IRQn                     = ADI_INT_RESET                      ,  /*!< RESET */
	NonMaskableint_IRQn            = ADI_INT_NMI                        ,  /*!< NonMaskable Interrupt */
	HardFault_IRQn                 = ADI_INT_HARD_FAULT                 ,  /*!< Hard Fault */
	SVCall_IRQn                    = ADI_INT_SVCALL                     ,  /*!< Service Call */
	PendSV_IRQn                    = ADI_INT_PENDSV                     ,  /*!< Pending Service */
	SysTick_IRQn                   = ADI_INT_SYSTICK                    ,  /*!< System Time Tick */
	CGU0_ERR_IRQn                  = ADI_INT_CGU0_ERR_EVT               ,  /*!< Error */
	CGU0_OSCW_INT_IRQn             = ADI_INT_CGU0_OSCW_INT_EVT          ,  /*!< Oscillator Watchdog Interrupt */
	OCU0_ERR_IRQn                  = ADI_INT_OCU0_ERR_EVT               ,  /*!< Freq. out-of-range, or dead clock, or counter overflow detected */
	VMU0_VDDEXT_EVT_IRQn           = ADI_INT_VMU0_VDDEXT_EVT            ,  /*!< External voltage management fault */
	VMU0_VDDINT_EVT_IRQn           = ADI_INT_VMU0_VDDINT_EVT            ,  /*!< Internal voltage management fault */
	CTI1_EVT0_IRQn                 = ADI_INT_CTI1_EVT0_EVT              ,  /*!< Cross Trigger Interface Event 0 */
	M0P_SRAM_EERR_IRQn             = ADI_INT_M0P_SRAM_EERR_EVT          ,  /*!< supervisor sram ecc error */
	SPU0_TIMEOUT_IRQn              = ADI_INT_SPU0_TIMEOUT_EVT           ,  /*!< Timeout Interrupt */
	C0_BUS_TIMEOUT_IRQn            = ADI_INT_C0_BUS_TIMEOUT_EVT         ,  /*!< Bus Timeout */
	C0_POSTWR_ERR_IRQn             = ADI_INT_C0_POSTWR_ERR_EVT          ,  /*!< Posted Write Error */
	MBOX0_PORT0_EERR_IRQn          = ADI_INT_MBOX0_PORT0_EERR_EVT       ,  /*!< Port 0 ECC error */
	FLC0_CORE_FLASH_EERR_IRQn      = ADI_INT_FLC0_CORE_FLASH_EERR_EVT   ,  /*!< Flash Core ECC Error */
	M4P_BUS_FAULT_IRQn             = ADI_INT_M4P_BUS_FAULT_EVT          ,  /*!< Bus Fault */
	M4P_CORE_SRAM_EERR_IRQn        = ADI_INT_M4P_CORE_SRAM_EERR_EVT     ,  /*!< SRAM Core ECC Error */
	M4P_LOCKUP_IRQn                = ADI_INT_M4P_LOCKUP_EVT             ,  /*!< Lockup Error (Fault only; not an interrupt) */
	MBOX0_PORT1_EERR_IRQn          = ADI_INT_MBOX0_PORT1_EERR_EVT       ,  /*!< Port 1 ECC error */
	SPU1_TIMEOUT_IRQn              = ADI_INT_SPU1_TIMEOUT_EVT           ,  /*!< Timeout Interrupt */
	C1_BUS_TIMEOUT_IRQn            = ADI_INT_C1_BUS_TIMEOUT_EVT         ,  /*!< Bus Timeout */
	FFTB0_DPERR_IRQn               = ADI_INT_FFTB0_DPERR_EVT            ,  /*!< Data parity error */
	FFTB0_SPERR_IRQn               = ADI_INT_FFTB0_SPERR_EVT            ,  /*!< Setup parity error */
	HAE0_PERR_IRQn                 = ADI_INT_HAE0_PERR_EVT              ,  /*!< Parity Error */
	CGU0_EVT_IRQn                  = ADI_INT_CGU0_EVT                   ,  /*!< Event */
	DPM0_EVT_IRQn                  = ADI_INT_DPM0_EVT                   ,  /*!< Event */
	SEC0_ERR_IRQn                  = ADI_INT_SEC0_ERR_EVT               ,  /*!< Error */
	SMPU0_ERR_IRQn                 = ADI_INT_SMPU0_ERR_EVT              ,  /*!< Error Interrupt */
	SPU0_INT_IRQn                  = ADI_INT_SPU0_INT_EVT               ,  /*!< Interrupt */
	WDOG0_EXP_IRQn                 = ADI_INT_WDOG0_EXP_EVT              ,  /*!< Expiration */
	SYS_AFE_LIMIT_IRQn             = ADI_INT_SYS_AFE_LIMIT_EVT          ,  /*!< AFE FOCP Limit Detection */
	SYS_AFE_NOTOK_IRQn             = ADI_INT_SYS_AFE_NOTOK_EVT          ,  /*!< AFE is functioning normally */
	SWU0_EVT_IRQn                  = ADI_INT_SWU0_EVT                   ,  /*!< Event */
	SWU1_EVT_IRQn                  = ADI_INT_SWU1_EVT                   ,  /*!< Event */
	DMA0_ERR_IRQn                  = ADI_INT_DMA0_ERR_EVT               ,  /*!< Error interrupt */
	DMA10_ERR_IRQn                 = ADI_INT_DMA10_ERR_EVT              ,  /*!< Error interrupt */
	DMA1_ERR_IRQn                  = ADI_INT_DMA1_ERR_EVT               ,  /*!< Error interrupt */
	DMA2_ERR_IRQn                  = ADI_INT_DMA2_ERR_EVT               ,  /*!< Error interrupt */
	DMA3_ERR_IRQn                  = ADI_INT_DMA3_ERR_EVT               ,  /*!< Error interrupt */
	DMA8_ERR_IRQn                  = ADI_INT_DMA8_ERR_EVT               ,  /*!< Error interrupt */
	DMA9_ERR_IRQn                  = ADI_INT_DMA9_ERR_EVT               ,  /*!< Error interrupt */
	ADCC0_ERR_IRQn                 = ADI_INT_ADCC0_ERR_EVT              ,  /*!< ADC Error */
	PINT0_BLOCK_IRQn               = ADI_INT_PINT0_BLOCK_EVT            ,  /*!< Pin Interrupt Block */
	TIMER0_STAT_IRQn               = ADI_INT_TIMER0_STAT_EVT            ,  /*!< Status */
	TIMER0_TMR0_IRQn               = ADI_INT_TIMER0_TMR0_EVT            ,  /*!< Timer 0 */
	TIMER0_TMR1_IRQn               = ADI_INT_TIMER0_TMR1_EVT            ,  /*!< Timer 1 */
	TIMER0_TMR2_IRQn               = ADI_INT_TIMER0_TMR2_EVT            ,  /*!< Timer 2 */
	TIMER0_TMR3_IRQn               = ADI_INT_TIMER0_TMR3_EVT            ,  /*!< Timer 3 */
	TIMER0_TMR4_IRQn               = ADI_INT_TIMER0_TMR4_EVT            ,  /*!< Timer 4 */
	TIMER0_TMR5_IRQn               = ADI_INT_TIMER0_TMR5_EVT            ,  /*!< Timer 5 */
	TIMER0_TMR6_IRQn               = ADI_INT_TIMER0_TMR6_EVT            ,  /*!< Timer 6 */
	TIMER0_TMR7_IRQn               = ADI_INT_TIMER0_TMR7_EVT            ,  /*!< Timer 7 */
	CPTMR0_CPT0_MEAS_IRQn          = ADI_INT_CPTMR0_CPT0_MEAS_EVT       ,  /*!< CPT 0 Measure Interrupt */
	CPTMR0_CPT1_MEAS_IRQn          = ADI_INT_CPTMR0_CPT1_MEAS_EVT       ,  /*!< CPT 1 Measure Interrupt */
	CPTMR0_CPT2_MEAS_IRQn          = ADI_INT_CPTMR0_CPT2_MEAS_EVT       ,  /*!< CPT 2 Measure Interrupt */
	DMA0_INT_IRQn                  = ADI_INT_DMA0_INT_EVT               ,  /*!< Done interrupt */
	DMA2_INT_IRQn                  = ADI_INT_DMA2_INT_EVT               ,  /*!< Done interrupt */
	DMA1_INT_IRQn                  = ADI_INT_DMA1_INT_EVT               ,  /*!< Done interrupt */
	DMA3_INT_IRQn                  = ADI_INT_DMA3_INT_EVT               ,  /*!< Done interrupt */
	DMA10_INT_IRQn                 = ADI_INT_DMA10_INT_EVT              ,  /*!< Done interrupt */
	DMA8_INT_IRQn                  = ADI_INT_DMA8_INT_EVT               ,  /*!< Done interrupt */
	DMA9_INT_IRQn                  = ADI_INT_DMA9_INT_EVT               ,  /*!< Done interrupt */
	TRU0_INT1_IRQn                 = ADI_INT_TRU0_INT1_EVT              ,  /*!< Interrupt request 1 */
	TRU1_INT4_IRQn                 = ADI_INT_TRU1_INT4_EVT              ,  /*!< Interrupt request 4 */
	FFTB0_DONE_IRQn                = ADI_INT_FFTB0_DONE_EVT             ,  /*!< FFT done */
	FFTB0_LIMERR_IRQn              = ADI_INT_FFTB0_LIMERR_EVT           ,  /*!< Over limit error */
	ADCC0_TMR0_EVT_IRQn            = ADI_INT_ADCC0_TMR0_EVT             ,  /*!< Timer 0 Event Complete */
	ADCC0_TMR1_EVT_IRQn            = ADI_INT_ADCC0_TMR1_EVT             ,  /*!< Timer 1 Event Complete */
	SPI0_ERR_IRQn                  = ADI_INT_SPI0_ERR_EVT               ,  /*!< Error */
	SPI0_STAT_IRQn                 = ADI_INT_SPI0_STAT_EVT              ,  /*!< Status */
	UART0_STAT_IRQn                = ADI_INT_UART0_STAT_EVT             ,  /*!< Status */
	HAE0_STAT_IRQn                 = ADI_INT_HAE0_STAT_EVT              ,  /*!< Status */
	CAN0_RX_IRQn                   = ADI_INT_CAN0_RX_EVT                ,  /*!< Receive */
	CAN0_STAT_IRQn                 = ADI_INT_CAN0_STAT_EVT              ,  /*!< Status */
	CAN0_TX_IRQn                   = ADI_INT_CAN0_TX_EVT                ,  /*!< Transmit */
	TWI0_DATA_IRQn                 = ADI_INT_TWI0_DATA_EVT              ,  /*!< Data Interrupt */
	MBOX0_PORT0_MSG_IRQn           = ADI_INT_MBOX0_PORT0_MSG_EVT        ,  /*!< Port 0 software interrupt */
	M0P_SOFT_INT0_IRQn             = ADI_INT_M0P_SOFT_INT0_EVT          ,  /*!< supervisor software-driven interrupt 0 */
} IRQn_Type;  /* typedef name for fixed interrupt numbers */


/*  =========================================================================
 *! \enum DMA_CHANn_TypeDef
 *! \brief  Interrupt Number Assignments
 *  ========================================================================= */
typedef enum
{
  SPI0_TXDMA_CHANn               =     0,    /*!< TX DMA Channel */
  SPI0_RXDMA_CHANn               =     1,    /*!< RX DMA Channel */
  UART0_TXDMA_CHANn              =     2,    /*!< Transmit DMA */
  UART0_RXDMA_CHANn              =     3,    /*!< Receive DMA */
  UART1_TXDMA_CHANn              =     4,    /*!< Transmit DMA */
  UART1_RXDMA_CHANn              =     5,    /*!< Receive DMA */
  SPI1_TXDMA_CHANn               =     6,    /*!< TX DMA Channel */
  UART2_TXDMA_CHANn              =     6,    /*!< Transmit DMA */
  SPI1_RXDMA_CHANn               =     7,    /*!< RX DMA Channel */
  UART2_RXDMA_CHANn              =     7,    /*!< Receive DMA */
  HAE0_RXDMA_CH0_CHANn           =     8,    /*!< TX0: DMA->HAE DATAI */
  UART3_TXDMA_CHANn              =     8,    /*!< Transmit DMA */
  HAE0_TXDMA_CHANn               =     9,    /*!< RX: HAE->DMA */
  UART3_RXDMA_CHANn              =     9,    /*!< Receive DMA */
  HAE0_RXDMA_CH1_CHANn           =    10,    /*!< TX1: DMA->HAE DATAV */
  SPORT0_A_DMA_CHANn             =    10,    /*!< Channel A DMA */
  UART4_TXDMA_CHANn              =    10,    /*!< Transmit DMA */
  SPORT0_B_DMA_CHANn             =    11,    /*!< Channel B DMA */
  UART4_RXDMA_CHANn              =    11,    /*!< Receive DMA */
  MDMA0_SRC_CHANn                =    12,    /*!< Memory DMA Stream n Source Channel */
  MDMA0_DST_CHANn                =    13,    /*!< Memory DMA Stream n Destination Channel */
} DMA_CHANn_TypeDef;  /* typedef name for fixed DMA channel assignments */



/*!
 * Device Error Code Offsets NEEDS REVISION FOR 350
 */
#define ADI_APP_USERERROR_OFFSET    0x00000100 /*!< Generic Device API Result Error Message Offset  */
#define ADI_DEV_GPT_ERROR_OFFSET    0x00000200 /*!< Error Offset for GP Timer API                   */
#define ADI_DEV_SYS_ERROR_OFFSET    0x00000300 /*!< Error Offset for System API                     */
#define ADI_DEV_PWR_ERROR_OFFSET    0x00000400 /*!< Error Offset for Power API                      */
#define ADI_DEV_EIR_ERROR_OFFSET    0x00000500 /*!< Error Offset for External Interrupt API         */
#define ADI_DEV_RST_ERROR_OFFSET    0x00000600 /*!< Error Offset for Reset API                      */
#define ADI_DEV_LFE_ERROR_OFFSET    0x00000700 /*!< Error Offset for Low Frequency Engine API       */
#define ADI_DEV_WUT_ERROR_OFFSET    0x00000800 /*!< Error Offset for Wakeup Timer API               */
#define ADI_DEV_WDT_ERROR_OFFSET    0x00000900 /*!< Error Offset for Watchdog Timer API             */
#define ADI_DEV_FLASH_ERROR_OFFSET  0x00000A00 /*!< Error Offset for Flash/EE API                   */
#define ADI_DEV_I2C_ERROR_OFFSET    0x00000B00 /*!< Error Offset for I2C API                        */
#define ADI_DEV_SPI_ERROR_OFFSET    0x00000C00 /*!< Error Offset for SPI API                        */
#define ADI_DEV_UART_ERROR_OFFSET   0x00000D00 /*!< Error Offset for UART API                       */
#define ADI_DEV_GPIO_ERROR_OFFSET   0x00000E00 /*!< Error Offset for GPIO API                       */
#define ADI_DEV_ANALOG_ERROR_OFFSET 0x00000F00 /*!< Error Offset for Misc. Analog API               */
#define ADI_DEV_UHF_ERROR_OFFSET    0x00001000 /*!< Error Offset for UHF API                        */
#define ADI_DEV_LFT_ERROR_OFFSET    0x00001100 /*!< Error Offset for Low Frerquency Transmitter API */
#define ADI_DEV_DMA_ERROR_OFFSET    0x00001200 /*!< Error Offset for DMA API                        */
#define ADI_DEV_ADC_ERROR_OFFSET    0x00001300 /*!< Error Offset for ADC API                        */
#define ADI_DEV_PWM_ERROR_OFFSET    0x00001400 /*!< Error Offset for PWM API                        */
#define ADI_DEV_AFE_ERROR_OFFSET    0x00001500 /*!< Error Offset for AFE API                        */

/******************************************************************************
 * Processor and Core Peripheral Section
 *****************************************************************************/
#define __MPU_PRESENT          0  /*!< MPU present or not                    */
#define __FPU_PRESENT          0  /*!< MPU present or not                    */
#define __NVIC_PRIO_BITS       2  /*!< Number of Bits for Priority Levels    */
#define __Vendor_SysTickConfig 0  /*!< 1 if different SysTick Config is used */



/******************************************************************************
 * Includes
 *****************************************************************************/

#include <core_cm0.h>    /* Cortex-M0 processor and core peripherals*/

/* SysTick Cycle Count Macros... max 24-bit measure (no wraparound handeling) */
#define CYCLES_INIT {                                                     \
    /* enable with internal clock and no interrupts */                    \
    SysTick->CTRL = SysTick_CTRL_CLKSOURCE_Msk | SysTick_CTRL_ENABLE_Msk; \
    SysTick->LOAD = 0x00FFFFFF;}                                     /*!< SysTick instruction count macro */
#define CYCLES_CLR     {SysTick->VAL = 0;}                           /*!< SysTick instruction count macro */
#define CYCLES_GET     (0x00ffffff - 5 - SysTick->VAL)               /*!< SysTick instruction count macro */
#define CYCLES_SUSPEND {SysTick->CTRL &= ~SysTick_CTRL_ENABLE_Msk;}  /*!< SysTick instruction count macro */
#define CYCLES_RESUME  {SysTick->CTRL |= SysTick_CTRL_ENABLE_Msk;}   /*!< SysTick instruction count macro */

/* need bool_t ahead of system.h */
#ifndef BOOL_TYPE
#define BOOL_TYPE /*!< Create a boolean type */

/*!
 * \typedef bool_t
 * boolean type, since use of C99 "bool" is not MISRA compliant
 */
typedef uint8_t  bool_t;

/* simple true/false defines for functional APIs */
#ifndef false
#define false 0u /*!< Create a boolean 'false' value */
#endif
#ifndef true
#define true 1u /*!< Create a boolean 'true' value */
#endif

#endif /* BOOL_TYPE */

#include "system.h"      /* System Header                           */

/* MIN */
#ifndef MIN
#define MIN(a,b) ((a) < (b) ? (a) : (b)) /*!< Define a handy 'MIN' macro */
#endif

/* MAX */
#ifndef MAX
#define MAX(a,b) ((a) > (b) ? (a) : (b)) /*!< Define a handy 'MAX' macro */
#endif


/*
 * Bit-Banding Macros for atomic RAM/MMR bit operations.
 * Compute the incoming RAM/MMR address and bit position
 * bit-banded address alias and set/clear the bit.
 */
 //FIXME: CHECK ADDRESSES HERE... TAKEN VERBATUM FROM SLATER...
#define RAM_ADR_BASE  0x20000000                                                                                      /*!< BitBanded address translation macro */
#define RAM_BB_ALIAS  0x22000000                                                                                      /*!< BitBanded address translation macro */
#define MMR_ADR_BASE  0x40000000                                                                                      /*!< BitBanded address translation macro */
#define MMR_BB_ALIAS  0x42000000                                                                                      /*!< BitBanded address translation macro */
#define MMR_BB_SET(a,b) ( *(volatile uint32_t *)(MMR_BB_ALIAS | (((uint32_t)a - MMR_ADR_BASE) << 5) | (b << 2)) = 1 ) /*!< BitBanded address translation macro */
#define MMR_BB_CLR(a,b) ( *(volatile uint32_t *)(MMR_BB_ALIAS | (((uint32_t)a - MMR_ADR_BASE) << 5) | (b << 2)) = 0 ) /*!< BitBanded address translation macro */
#define RAM_BB_SET(a,b) ( *(volatile uint32_t *)(RAM_BB_ALIAS | (((uint32_t)a - RAM_ADR_BASE) << 5) | (b << 2)) = 1 ) /*!< BitBanded address translation macro */
#define RAM_BB_CLR(a,b) ( *(volatile uint32_t *)(RAM_BB_ALIAS | (((uint32_t)a - RAM_ADR_BASE) << 5) | (b << 2)) = 0 ) /*!< BitBanded address translation macro */

/******************************************************************************
 * ADuM350 Device Specific Peripheral registers structures
 *****************************************************************************/
#if defined ( __CC_ARM   )
#pragma anon_unions
#endif


/******************************************************************************
 *  Access Modifiers used in the device templates following:                  *
 *    __IO = read/write register                                              *
 *    __I  = read-only register                                               *
 *    __O  = write-only register                                              *
 *****************************************************************************/


/* include CODA-generated device memory maps */
#include "CM41x_M0_device.h"

/* missing CODA defines */
//#define ENUM_SEC_CSTAT_ACKERR                (_ADI_MSK(0x00000010,uint32_t))  /* ERRC: Acknowledge Error */

// create singular GPT idle mode...
// (see http://labrea.ad.analog.com/browse/ADUCS06-39 "Multiple Timer Idle Modes Don't Exist on Tesla")
#define ENUM_TIMER_TMR_CFG_IDLE_MODE          (0x00000000)  /* TMODE: Idle Mode */

/* map old-to-new UART IMASK macros (without "_IMSK_" component added in new CODA defines) */
#define ENUM_UART_CTL_1_EXTRA_STBH      ENUM_UART_CTL_ONE_EXTRA_STBH      /*  STBH: 1 half-bit-time stop bit */
#define ENUM_UART_CTL_1_EXTRA_STB       ENUM_UART_CTL_ONE_EXTRA_STB       /*  STB: 2 stop bits */
#define ENUM_UART_ETXS_LO               ENUM_UART_IMSK_ETXS_LO            /*  ETXS: Interrupt is masked */
#define ENUM_UART_ETXS_HI               ENUM_UART_IMSK_ETXS_HI            /*  ETXS: Interrupt is unmasked */
#define ENUM_UART_ERXS_LO               ENUM_UART_IMSK_ERXS_LO            /*  ERXS: Interrupt is masked */
#define ENUM_UART_ERXS_HI               ENUM_UART_IMSK_ERXS_HI            /*  ERXS: Interrupt is unmasked */
#define ENUM_UART_EAWI_LO               ENUM_UART_IMSK_EAWI_LO            /*  EAWI: Interrupt is masked */
#define ENUM_UART_EAWI_HI               ENUM_UART_IMSK_EAWI_LO            /*  EAWI: Interrupt is unmasked */
#define ENUM_UART_ERFCI_LO              ENUM_UART_IMSK_ERFCI_LO           /*  ERFCI: Interrupt is masked */
#define ENUM_UART_ERFCI_HI              ENUM_UART_IMSK_ERFCI_HI           /*  ERFCI: Interrupt is unmasked */
#define ENUM_UART_ETFI_LO               ENUM_UART_IMSK_ETFI_LO            /*  ETFI: Interrupt is masked */
#define ENUM_UART_ETFI_HI               ENUM_UART_IMSK_ETFI_HI            /*  ETFI: Interrupt is unmasked */
#define ENUM_UART_EDTPTI_LO             ENUM_UART_IMSK_EDTPTI_LO          /*  EDTPTI: Interrupt is masked */
#define ENUM_UART_EDTPTI_HI             ENUM_UART_IMSK_EDTPTI_HI          /*  EDTPTI: Interrupt is unmasked */
#define ENUM_UART_EDSSI_LO              ENUM_UART_IMSK_EDSSI_LO           /*  EDSSI: Interrupt is masked */
#define ENUM_UART_EDSSI_HI              ENUM_UART_IMSK_EDSSI_HI           /*  EDSSI: Interrupt is unmasked */
#define ENUM_UART_ELSI_LO               ENUM_UART_IMSK_ELSI_LO            /*  ELSI: Interrupt is masked */
#define ENUM_UART_ELSI_HI               ENUM_UART_IMSK_ELSI_HI            /*  ELSI: Interrupt is unmasked */
#define ENUM_UART_ETBEI_LO              ENUM_UART_IMSK_ETBEI_LO           /*  ETBEI: Interrupt is masked */
#define ENUM_UART_ETBEI_HI              ENUM_UART_IMSK_ETBEI_HI           /*  ETBEI: Interrupt is unmasked */
#define ENUM_UART_ERBFI_LO              ENUM_UART_IMSK_ERBFI_LO           /*  ERBFI: Interrupt is masked */
#define ENUM_UART_ERBFI_HI              ENUM_UART_IMSK_ERBFI_HI           /*  ERBFI: Interrupt is unmasked */

/* C++ linkage */
#ifdef __cplusplus
}
#endif

#endif /* include guard */

/*
** EOF
*/

/*@}*/
