/*********************************************************************************

Copyright(c) 2011 Analog Devices, Inc. All Rights Reserved.

This software is proprietary and confidential.  By using this software you agree
to the terms of the associated Analog Devices License Agreement.

*********************************************************************************/

/** @addtogroup DMA_Manager DMA Manager
 *  @{
 */

/*!
 * @file    adi_dma.h
 * @brief   DMA Manager definitions and API
 * @version $Revision: 30757 $
 * @date    $Date: 2015-04-24 16:33:48 -0400 (Fri, 24 Apr 2015) $
 *
 * @details
 *            This is the primary header file for the DMA Manager service
 */

#ifndef __ADI_DMA_H__
#define __ADI_DMA_H__

/*=============  I N C L U D E S   =============*/

/* Platform specific includes */
#include <sys/platform.h>
/* Data type definitions */
#include <stdint.h>
/* Interrupt Manager includes */
#include <services/int/adi_int.h>

/* ADSP-BF60x Processor family or
   ADI_ADSP_CM40z processor family or
   ADSPBF70x Processor family
   ADSP5SC58x Processor family */
#if defined (__ADSPBF609_FAMILY__) || \
    defined (  ADI_ADSP_CM40Z    ) || \
    defined (  ADI_ADSP_CM41X    ) || \
    defined (__ADSPBF707_FAMILY__) || \
    defined (__ADSPSC589_FAMILY__)

/* Memory DMA Manager includes */
#include <services/dma/adi_mdma_bf60x.h>
/* Peripheral DMA Manager includes */
#include <services/dma/adi_pdma_bf60x.h>

/* ADSP-BF5xx Processor family */
#elif defined (__ADSPBF5xx__)

/* Memory DMA Manager includes */
#include <services/dma/adi_mdma_bf5xx.h>
/* Peripheral DMA Manager includes */
#include <services/dma/adi_pdma_bf5xx.h>

#else
#error Processor not supported
#endif /* __ADSPBF60x__ */

#endif  /* __ADI_DMA_H__ */

/*****/

/*
** EOF
*/

/*@}*/


