/*********************************************************************************

Copyright(c) 2011 Analog Devices, Inc. All Rights Reserved.

This software is proprietary and confidential.  By using this software you agree
to the terms of the associated Analog Devices License Agreement.

*********************************************************************************/

/*!
 * @file:    adi_pdma_channels_cm41x.h
 * @brief:   Peripheral DMA Channel ID definitions for ADSP-CM41X processor family
 * @version: $Revision: 30986 $
 * @date:    $Date: 2015-05-08 11:50:36 -0400 (Fri, 08 May 2015) $
 *
 * @details
 *           This is an additional header file for the Peripheral DMA Manager service of
 *           ADSP-CM41X processor family, which contains the Peripheral DMA Channel ID
 *           definitions used in the APIs
 */

#ifndef __ADI_PDMA_CHANNELS_CM41X_H__
#define __ADI_PDMA_CHANNELS_CM41X_H__

/*==============  D E F I N E S  ===============*/

/* ADSP-CM402/CM403/CM407/CM408 processors */
#if defined(ADI_ADSP_CM41X)

/** @ingroup PDMA_Manager
 *  DMA Channel IDs for ADSP_CM41X processors
 */
typedef enum
{
	/* NOTE shared channels (13 channels shared across 21 devices) */
    ADI_DMA_CHNL_SPI0_TX     = SPI0_TXDMA_CHANn,         /*!< DMA  0 - SPI0 TX */
    ADI_DMA_CHNL_SPI0_RX     = SPI0_RXDMA_CHANn,         /*!< DMA  1 - SPI0 RX */
    ADI_DMA_CHNL_UART0_TX    = UART0_TXDMA_CHANn,        /*!< DMA  2 - UART0 TX */
    ADI_DMA_CHNL_UART0_RX    = UART0_RXDMA_CHANn,        /*!< DMA  3 - UART0 RX */
    ADI_DMA_CHNL_UART1_TX    = UART1_TXDMA_CHANn,        /*!< DMA  4 - UART1 TX */
    ADI_DMA_CHNL_UART1_RX    = UART1_RXDMA_CHANn,        /*!< DMA  5 - UART1 RX */
    ADI_DMA_CHNL_SPI1_TX     = SPI1_TXDMA_CHANn,         /*!< DMA  6 - SPI1 TX */
    ADI_DMA_CHNL_UART2_TX    = UART2_TXDMA_CHANn,        /*!< DMA  6 - UART2 TX */
    ADI_DMA_CHNL_SPI1_RX     = SPI1_RXDMA_CHANn,         /*!< DMA  7 - SPI1 RX */
    ADI_DMA_CHNL_UART2_RX    = UART2_RXDMA_CHANn,        /*!< DMA  7 - UART2 RX */
    ADI_DMA_CHNL_HAE0_RX_CH0 = HAE0_RXDMA_CH0_CHANn,     /*!< DMA  8 - Harmonic Analysis Engine (HAE) RX DMA Channel 0 */
    ADI_DMA_CHNL_UART3_TX    = UART3_TXDMA_CHANn,        /*!< DMA  8 - UART3 TX */
    ADI_DMA_CHNL_HAE0_TX     = HAE0_TXDMA_CHANn,         /*!< DMA  9 - Harmonic Analysis Engine (HAE) TX DMA */
    ADI_DMA_CHNL_UART3_RX    = UART3_RXDMA_CHANn,        /*!< DMA  9 - UART3 RX */
    ADI_DMA_CHNL_HAE0_RX_CH1 = HAE0_RXDMA_CH1_CHANn,     /*!< DMA 10 - Harmonic Analysis Engine (HAE) RX DMA Channel 1 */
    ADI_DMA_CHNL_SPORT0_A    = SPORT0_A_DMA_CHANn,       /*!< DMA 10 - SPORT0 Channel A */
    ADI_DMA_CHNL_UART4_TX    = UART4_TXDMA_CHANn,        /*!< DMA 10 - UART4 TX */
    ADI_DMA_CHNL_SPORT0_B    = SPORT0_B_DMA_CHANn,       /*!< DMA 11 - SPORT0 Channel B */
    ADI_DMA_CHNL_UART4_RX    = UART4_RXDMA_CHANn,        /*!< DMA 11 - UART4 RX */
    ADI_DMA_CHNL_MEMDMA_S0   = MDMA0_SRC_CHANn,          /*!< DMA 12 - MDMA0 Source Input */
    ADI_DMA_CHNL_MEMDMA_D0   = MDMA0_DST_CHANn,          /*!< DMA 13 - MDMA0 Destination Output */

    ADI_DMA_CHANNEL_END	     = (14u)                    /* End of DMA Channel listing */

} ADI_DMA_CHANNEL_ID;

#endif  /* ADI_ADSP_CM41X  */

#endif  /* __ADI_PDMA_CHANNELS_CM40Z_H__ */

/*****/

/*@}*/

