/*!
 *****************************************************************************
 * @file:    adi_sid_cm40z.h
 * @brief:   Defenition of interrupt IDs using which application/drivers
             register/unregister interrupt handlers.
 * @version: $Revision: 30871 $
 * @date:    $Date: 2015-05-01 13:22:40 -0400 (Fri, 01 May 2015) $
 *-----------------------------------------------------------------------------
 *
Copyright (c) 2010 Analog Devices, Inc.

All rights reserved.

Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:
  - Redistributions of source code must retain the above copyright notice,
    this list of conditions and the following disclaimer.
  - Redistributions in binary form must reproduce the above copyright notice,
    this list of conditions and the following disclaimer in the documentation
    and/or other materials provided with the distribution.
  - Modified versions of the software must be conspicuously marked as such.
  - This software is licensed solely and exclusively for use with processors
    manufactured by or for Analog Devices, Inc.
  - This software may not be combined or merged with other code in any manner
    that would cause the software to become subject to terms and conditions
    which differ from those listed here.
  - Neither the name of Analog Devices, Inc. nor the names of its
    contributors may be used to endorse or promote products derived
    from this software without specific prior written permission.
  - The use of this software may or may not infringe the patent rights of one
    or more patent holders.  This license does not release you from the
    requirement that you obtain separate licenses from these patent holders
    to use this software.

THIS SOFTWARE IS PROVIDED BY ANALOG DEVICES, INC. AND CONTRIBUTORS "AS IS" AND ANY
EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, NON-INFRINGEMENT,
TITLE, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN
NO EVENT SHALL ANALOG DEVICES, INC. OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, PUNITIVE OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, DAMAGES ARISING OUT OF CLAIMS OF INTELLECTUAL
PROPERTY RIGHTS INFRINGEMENT; PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

**********************************************************************************/


/* Cortex-M4 processor exceptions */
#define ADI_INT_RESET                     -15  // Reset Interrupt
#define ADI_INT_NMI                       -14  // Non Maskable Interrupt
#define ADI_INT_HARD_FAULT                -13  // Hard Fault Interrupt
//                                        -12     Reserved
//                                        -11     Reserved
//                                        -10     Reserved
//                                         -9
//                                         -8     Reserved
//                                         -7     Reserved
//                                         -6     Reserved
#define ADI_INT_SVCALL                     -5  // System Service Call Interrupt
//                                         -4     Reserved
//                                         -3     Reserved
#define ADI_INT_PENDSV                     -2  // Pendable request for system device Interrupt
#define ADI_INT_SYSTICK                    -1  // System Tick Interrupt


/* ADSP-CM41x M0 Specific Interrupts (many of which are shared...) */
#define ADI_INT_CGU0_ERR_EVT               0  /*!< Error */
#define ADI_INT_CGU0_OSCW_INT_EVT          0  /*!< Oscillator Watchdog Interrupt */
#define ADI_INT_OCU0_ERR_EVT               0  /*!< Freq. out-of-range, or dead clock, or counter overflow detected */
#define ADI_INT_VMU0_VDDEXT_EVT            0  /*!< External voltage management fault */
#define ADI_INT_VMU0_VDDINT_EVT            0  /*!< Internal voltage management fault */
#define ADI_INT_CTI1_EVT0_EVT              1  /*!< Cross Trigger Interface Event 0 */
#define ADI_INT_M0P_SRAM_EERR_EVT          2  /*!< supervisor sram ecc error */
#define ADI_INT_SPU0_TIMEOUT_EVT           3  /*!< Timeout Interrupt */
#define ADI_INT_C0_BUS_TIMEOUT_EVT         3  /*!< Bus Timeout */
#define ADI_INT_C0_POSTWR_ERR_EVT          3  /*!< Posted Write Error */
#define ADI_INT_MBOX0_PORT0_EERR_EVT       4  /*!< Port 0 ECC error */
#define ADI_INT_FLC0_CORE_FLASH_EERR_EVT   5  /*!< Flash Core ECC Error */
#define ADI_INT_M4P_BUS_FAULT_EVT          5  /*!< Bus Fault */
#define ADI_INT_M4P_CORE_SRAM_EERR_EVT     5  /*!< SRAM Core ECC Error */
#define ADI_INT_M4P_LOCKUP_EVT             5  /*!< Lockup Error (Fault only; not an interrupt) */
#define ADI_INT_MBOX0_PORT1_EERR_EVT       5  /*!< Port 1 ECC error */
#define ADI_INT_SPU1_TIMEOUT_EVT           5  /*!< Timeout Interrupt */
#define ADI_INT_C1_BUS_TIMEOUT_EVT         5  /*!< Bus Timeout */
#define ADI_INT_FFTB0_DPERR_EVT            6  /*!< Data parity error */
#define ADI_INT_FFTB0_SPERR_EVT            6  /*!< Setup parity error */
#define ADI_INT_HAE0_PERR_EVT              6  /*!< Parity Error */
#define ADI_INT_CGU0_EVT                   7  /*!< Event */
#define ADI_INT_DPM0_EVT                   7  /*!< Event */
#define ADI_INT_SEC0_ERR_EVT               8  /*!< Error */
#define ADI_INT_SMPU0_ERR_EVT              8  /*!< Error Interrupt */
#define ADI_INT_SPU0_INT_EVT               8  /*!< Interrupt */
#define ADI_INT_WDOG0_EXP_EVT              9  /*!< Expiration */
#define ADI_INT_SYS_AFE_LIMIT_EVT         10  /*!< AFE FOCP Limit Detection */
#define ADI_INT_SYS_AFE_NOTOK_EVT         10  /*!< AFE is functioning normally */
#define ADI_INT_SWU0_EVT                  11  /*!< Event */
#define ADI_INT_SWU1_EVT                  11  /*!< Event */
#define ADI_INT_DMA0_ERR_EVT              12  /*!< Error interrupt */
#define ADI_INT_DMA10_ERR_EVT             12  /*!< Error interrupt */
#define ADI_INT_DMA1_ERR_EVT              12  /*!< Error interrupt */
#define ADI_INT_DMA2_ERR_EVT              12  /*!< Error interrupt */
#define ADI_INT_DMA3_ERR_EVT              12  /*!< Error interrupt */
#define ADI_INT_DMA8_ERR_EVT              12  /*!< Error interrupt */
#define ADI_INT_DMA9_ERR_EVT              12  /*!< Error interrupt */
#define ADI_INT_ADCC0_ERR_EVT             13  /*!< ADC Error */
#define ADI_INT_PINT0_BLOCK_EVT           14  /*!< Pin Interrupt Block */
#define ADI_INT_TIMER0_STAT_EVT           15  /*!< Status */
#define ADI_INT_TIMER0_TMR0_EVT           15  /*!< Timer 0 */
#define ADI_INT_TIMER0_TMR1_EVT           15  /*!< Timer 1 */
#define ADI_INT_TIMER0_TMR2_EVT           15  /*!< Timer 2 */
#define ADI_INT_TIMER0_TMR3_EVT           15  /*!< Timer 3 */
#define ADI_INT_TIMER0_TMR4_EVT           15  /*!< Timer 4 */
#define ADI_INT_TIMER0_TMR5_EVT           15  /*!< Timer 5 */
#define ADI_INT_TIMER0_TMR6_EVT           15  /*!< Timer 6 */
#define ADI_INT_TIMER0_TMR7_EVT           15  /*!< Timer 7 */
#define ADI_INT_CPTMR0_CPT0_MEAS_EVT      16  /*!< CPT 0 Measure Interrupt */
#define ADI_INT_CPTMR0_CPT1_MEAS_EVT      16  /*!< CPT 1 Measure Interrupt */
#define ADI_INT_CPTMR0_CPT2_MEAS_EVT      16  /*!< CPT 2 Measure Interrupt */
#define ADI_INT_DMA0_INT_EVT              17  /*!< Done interrupt */
#define ADI_INT_DMA2_INT_EVT              17  /*!< Done interrupt */
#define ADI_INT_DMA1_INT_EVT              18  /*!< Done interrupt */
#define ADI_INT_DMA3_INT_EVT              18  /*!< Done interrupt */
#define ADI_INT_DMA10_INT_EVT             19  /*!< Done interrupt */
#define ADI_INT_DMA8_INT_EVT              19  /*!< Done interrupt */
#define ADI_INT_DMA9_INT_EVT              19  /*!< Done interrupt */
#define ADI_INT_TRU0_INT1_EVT             20  /*!< Interrupt request 1 */
#define ADI_INT_TRU1_INT4_EVT             21  /*!< Interrupt request 4 */
#define ADI_INT_FFTB0_DONE_EVT            22  /*!< FFT done */
#define ADI_INT_FFTB0_LIMERR_EVT          22  /*!< Over limit error */
#define ADI_INT_ADCC0_TMR0_EVT            23  /*!< Timer 0 Event Complete */
#define ADI_INT_ADCC0_TMR1_EVT            24  /*!< Timer 1 Event Complete */
#define ADI_INT_SPI0_ERR_EVT              25  /*!< Error */
#define ADI_INT_SPI0_STAT_EVT             25  /*!< Status */
#define ADI_INT_UART0_STAT_EVT            26  /*!< Status */
#define ADI_INT_HAE0_STAT_EVT             27  /*!< Status */
#define ADI_INT_CAN0_RX_EVT               28  /*!< Receive */
#define ADI_INT_CAN0_STAT_EVT             28  /*!< Status */
#define ADI_INT_CAN0_TX_EVT               28  /*!< Transmit */
#define ADI_INT_TWI0_DATA_EVT             29  /*!< Data Interrupt */
#define ADI_INT_MBOX0_PORT0_MSG_EVT       30  /*!< Port 0 software interrupt */
#define ADI_INT_M0P_SOFT_INT0_EVT         31  /*!< supervisor software-driven interrupt 0 */

/* Update this based on the number of interrupts */
#define ADI_INT_NUM_INT         32          /* Number of Interrupts */

