/*
 *****************************************************************************
 * @file:    adi_uart_data_bf60x.c
 * @brief:   Data declaration for UART Device Driver for BF60x family processor
 * @version: $Revision: 31024 $
 * @date:    $Date: 2015-05-12 12:02:06 -0400 (Tue, 12 May 2015) $
 *****************************************************************************

Copyright(c) 2011 Analog Devices, Inc. All Rights Reserved.

This software is proprietary and confidential.  By using this software you agree
to the terms of the associated Analog Devices License Agreement.

*********************************************************************************/
/*!
* @file      adi_uart_data_cm40z.c
*
* @brief     This file contains the data defenition required by UART driver.
*
*/


#ifdef _MISRA_RULES
#pragma diag(push)
#pragma diag(suppress:misra_rule_2_4:"Allows portions of code to be commented out")
#pragma diag(suppress:misra_rule_5_1:"Allow identifiers to be more than 31 characters")
#pragma diag(suppress:misra_rule_5_6:"Allow identifier names to be reused in different name spaces")
#pragma diag(suppress:misra_rule_5_7:"Allow identifier names to be reused")
#pragma diag(suppress:misra_rule_8_5:"Allow defenition of objects in the source file. MISRA treats this as header file.")
#pragma diag(suppress:misra_rule_8_7:"Allow objects to be defined outside the block eventhough they are used in one function, for ease maintainence.")
#pragma diag(suppress:misra_rule_14_7:"Allow multiple exits from a function for readability and optimized code")
#pragma diag(suppress:misra_rule_17_4:"Allow pointer arithmetic for MMR address generation")
#pragma diag(suppress:misra_rule_19_7:"Allow macros to be used for readability")
#endif /* _MISRA_RULES */


#if defined(ADI_ADSP_CM41X)

static ADI_UART_INFO gUARTDevInfo[]   =
{
    /* UART 0 */
    {
        (volatile ADI_UART_REGS *)REG_UART0_CTL,    /* First UART register address */
        ADI_DMA_CHNL_UART0_TX,                      /* UART0 Tx DMA Channel ID */
        ADI_DMA_CHNL_UART0_RX,                      /* UART0 Rx DMA Channel ID */
        (uint32_t)INTR_UART0_STAT,                  /* UART0 Status interrupt ID */
        NULL                                        /* Pointer to UART device instance data */
    },

#if defined(ADI_ADSP_CM41X_M4)
    
	/* UART1 through UART4 are exclusive to the M4 core */

    /* UART 1 */
    {
        (volatile ADI_UART_REGS *)REG_UART1_CTL,    /* First UART register address */
        ADI_DMA_CHNL_UART1_TX,                      /* UART1 Tx DMA Channel ID */
        ADI_DMA_CHNL_UART1_RX,                      /* UART1 Rx DMA Channel ID */
        (uint32_t)INTR_UART1_STAT,                  /* UART1 Status interrupt ID */
        NULL                                        /* Pointer to UART device instance data */
    },

	/* UART 2 */
    {
        (volatile ADI_UART_REGS *)REG_UART2_CTL,    /* First UART register address */
        ADI_DMA_CHNL_UART2_TX,                      /* UART2 Tx DMA Channel ID */
        ADI_DMA_CHNL_UART2_RX,                      /* UART2 Rx DMA Channel ID */
        (uint32_t)INTR_UART2_STAT,                  /* UART2 Status interrupt ID */
        NULL                                        /* Pointer to UART device instance data */
    },

	/* UART 3 */
    {
        (volatile ADI_UART_REGS *)REG_UART3_CTL,    /* First UART register address */
        ADI_DMA_CHNL_UART3_TX,                      /* UART3 Tx DMA Channel ID */
        ADI_DMA_CHNL_UART3_RX,                      /* UART3 Rx DMA Channel ID */
        (uint32_t)INTR_UART3_STAT,                  /* UART3 Status interrupt ID */
        NULL                                        /* Pointer to UART device instance data */
    },

	/* UART 4 */
    {
        (volatile ADI_UART_REGS *)REG_UART4_CTL,    /* First UART register address */
        ADI_DMA_CHNL_UART4_TX,                      /* UART4 Tx DMA Channel ID */
        ADI_DMA_CHNL_UART4_RX,                      /* UART4 Rx DMA Channel ID */
        (uint32_t)INTR_UART4_STAT,                  /* UART4 Status interrupt ID */
        NULL                                        /* Pointer to UART device instance data */
    }
#endif /* ADI_ADSP_CM41X_M4 */
};

#else
#error The UART driver is not ported for this processor
#endif /* ADI_ADSP_CM41X */


#ifdef _MISRA_RULES
#pragma diag(pop)
#endif
