/*********************************************************************************

Copyright(c) 2011 Analog Devices, Inc. All Rights Reserved.

This software is proprietary and confidential.  By using this software you agree
to the terms of the associated Analog Devices License Agreement.

*********************************************************************************/
/*!
 * @file      adi_dma_data_cm40z.c
 * @brief     ADSP-CM40z processor specific data for DMA Manager.
 * @version:  $Revision: 31024 $
 * @date:     $Date: 2015-05-12 12:02:06 -0400 (Tue, 12 May 2015) $
 *
 * @details
 *            This is an additional source file for DMA Manager Service
 *            for ADSP-CM40z processor. This file contains processor specific
 *            data for ADSP-CM40z processor family.
 *
 */

/** @addtogroup DMA_Manager DMA Manager
 *  @{
 */

#ifdef _MISRA_RULES
#pragma diag(push)
#pragma diag(suppress:misra_rule_5_1:"Allow identifiers to be more than 31 characters")
#pragma diag(suppress:misra_rule_8_5:"Objects defined in this source files are common to MDMA and PDMA source files")
#pragma diag(suppress:misra_rule_8_7:"Allow objects to be defined in a common file")
#pragma diag(suppress:misra_rule_9_2:" ")
#pragma diag(suppress:misra_rule_10_1_a:" ")
#endif /* _MISRA_RULES */

/*=============  P R O C E S S O R    S P E C I F I C     D A T A  =============*/

/* ADSP-CM402/CM403/CM407/CM408 processors */
#if defined(ADI_ADSP_CM41X)

/* Interrupt ID for Reserved DMA channel */
#define ADI_DMA_RSV_INTR_ID                     (255u)
/* DMA Channel specific information */
static ADI_DMA_INFO     ChannelInfo[] =
{
	/* NOTE shared channels (M4 shares 13 channels shared across 21 devices, M0 has no shared channels) */
   { INTR_SPI0_TXDMA_INT,     INTR_SPI0_TXDMA_ERR,         (volatile ADI_DMA_REGS *) REG_DMA0_DSCPTR_NXT,  NULL }, /* DMA  0 - dedicated to SPI0 TX        */
   { INTR_SPI0_RXDMA_INT,     INTR_SPI0_RXDMA_ERR,         (volatile ADI_DMA_REGS *) REG_DMA1_DSCPTR_NXT,  NULL }, /* DMA  1 - dedicated to SPI0 RX        */
   { INTR_UART0_TXDMA_INT,    INTR_UART0_TXDMA_ERR,        (volatile ADI_DMA_REGS *) REG_DMA2_DSCPTR_NXT,  NULL }, /* DMA  2 - dedicated to UART0 TX       */
   { INTR_UART0_RXDMA_INT,    INTR_UART0_RXDMA_ERR,        (volatile ADI_DMA_REGS *) REG_DMA3_DSCPTR_NXT,  NULL }, /* DMA  3 - dedicated to UART0 RX       */

#if defined(ADI_ADSP_CM41X_M4)
   
   /* DMA channels 4 through 14 are exclusive to the M4 core */
   { INTR_UART1_TXDMA_INT,    INTR_UART1_TXDMA_ERR,        (volatile ADI_DMA_REGS *) REG_DMA4_DSCPTR_NXT,  NULL }, /* DMA  4 - dedicated to UART1 TX       */
   { INTR_UART1_RXDMA_INT,    INTR_UART1_RXDMA_ERR,        (volatile ADI_DMA_REGS *) REG_DMA5_DSCPTR_NXT,  NULL }, /* DMA  5 - dedicated to UART1 RX       */
   { INTR_DMA6_INT,           INTR_DMA6_ERR,               (volatile ADI_DMA_REGS *) REG_DMA6_DSCPTR_NXT,  NULL }, /* DMA  6 - shared amoung:
                                                                                                                                 INTR_SPI1_TXDMA_INT
                                                                                                                                 INTR_UART2_TXDMA_INT      */
   { INTR_DMA7_INT,           INTR_DMA7_ERR,               (volatile ADI_DMA_REGS *) REG_DMA7_DSCPTR_NXT,  NULL }, /* DMA  7 - shared amoung:
                                                                                                                                 INTR_SPI1_RXDMA_INT
                                                                                                                                 INTR_UART2_RXDMA_INT      */
   { INTR_DMA8_INT,           INTR_DMA8_ERR,               (volatile ADI_DMA_REGS *) REG_DMA8_DSCPTR_NXT,  NULL }, /* DMA  8 - shared amoung:
                                                                                                                                 INTR_HAE0_RXDMA_CH0_INT
                                                                                                                                 INTR_UART3_TXDMA_INT      */
   { INTR_DMA9_INT,           INTR_DMA9_ERR,               (volatile ADI_DMA_REGS *) REG_DMA9_DSCPTR_NXT,  NULL }, /* DMA  9 - shared amoung:
                                                                                                                                 INTR_HAE0_TXDMA_INT
                                                                                                                                 INTR_UART3_RXDMA_INT      */
   { INTR_DMA10_INT,          INTR_DMA10_ERR,              (volatile ADI_DMA_REGS *) REG_DMA10_DSCPTR_NXT, NULL }, /* DMA 10 - shared among:
                                                                                                                                 INTR_HAE0_RXDMA_CH1_INT
                                                                                                                                 INTR_SPORT0_A_DMA_INT
                                                                                                                                 INTR_UART4_TXDMA_INT      */
   { INTR_DMA11_INT,          INTR_DMA11_ERR,              (volatile ADI_DMA_REGS *) REG_DMA11_DSCPTR_NXT, NULL }, /* DMA 11 - shared among:
                                                                                                                                 INTR_SPORT0_B_DMA_INT
                                                                                                                                 INTR_UART4_RXDMA_INT      */
   { INTR_MDMA0_SRC_INT,      INTR_MDMA0_SRC_ERR,          (volatile ADI_DMA_REGS *) REG_DMA12_DSCPTR_NXT, NULL }, /* DMA 12 - dedicated to MDMA0 SRC      */
   { INTR_MDMA0_DST_INT,      INTR_MDMA0_DST_ERR,          (volatile ADI_DMA_REGS *) REG_DMA13_DSCPTR_NXT, NULL }, /* DMA 13 - dedicated to MDMA0 DST      */
#endif /* ADI_ADSP_CM41X_M4 */
};

/* Total number of DMA Channels available in this processor family */
#define ADI_DMA_TOTAL_NUM_CHANNELS  (sizeof(ChannelInfo)/sizeof(ChannelInfo[0]))

/* Memory DMA Stream specific information */
static const ADI_DMA_MEM_STREAM_INFO    StreamInfo[] =
{
    { ADI_DMA_CHNL_MEMDMA_D0, ADI_DMA_CHNL_MEMDMA_S0 },  /* MDMA Stream 0 Source & Destination channel IDs */
};

#endif /* ADI_ADSP_CM41X */

#ifdef _MISRA_RULES
#pragma diag(pop)
#endif /* _MISRA_RULES */

/*****/

/*@}*/

