/*********************************************************************************

Copyright(c) 2013 Analog Devices, Inc. All Rights Reserved.

This software is proprietary and confidential.  By using this software you agree
to the terms of the associated Analog Devices License Agreement.

*********************************************************************************/
/*!
* @file      adi_int.c
*
* @brief     Interrupt handler installation API implementation
*
* @details
*            This is the primary API header file for installing interrupt 
*            handlers for all types of interrupts on the blackfin processor.
*/

/*! @addtogroup Interrupt_Install Processor-independent Interrupt APIs
 *  @{
 */

/* In Blackfin or SHARC compilers we need to include a header in order to get
 * the correct macro definition. 
 */
// FIXME: this should be an unconditional include, as all targest should use platform.h to
// pick up "feature macros".  But for now, just add "__ICCARM__" for Tesla (IAR compiler)
#if defined (__ADSPSHARC__) || defined (__ADSPBLACKFIN__) || defined (__ADSPSC589_FAMILY__) || defined (__ICCARM__)
#include <sys/platform.h>
#endif

/* SHARC and Blackfin with a SEC use it in adi int */
#if (defined (__ADSPSHARC__) || defined (__ADSPBLACKFIN__))  && defined (__ADI_HAS_SEC__)
#define __ADI_INT_USE_SEC__
#endif

#if defined (__ADSPBLACKFIN__) &&!defined (__ADI_HAS_SEC__)
#define __ADI_INT_USE_SIC__
#endif

#if defined (__ADSPSHARC__) &&!defined (__ADI_HAS_SEC__)
#define __ADI_INT_USE_21XXX__
#endif

#if defined (ADI_ADSP_CM40Z) || defined (ADI_ADSP_CM41X) || defined (ADI_ADUCM350)
#define __ADI_INT_USE_NVIC__
#endif

#if defined (__ADI_HAS_GICDST__) && defined (__ADSPARM__)
#define __ADI_INT_USE_GIC__
#endif


#if defined(__ADI_INT_USE_SEC__)
#include "adi_int_sec.c"
#elif defined (__ADI_INT_USE_SIC__)
#include "adi_int_sic.c"
#elif defined (__ADI_INT_USE_NVIC__)
#include "adi_int_nvic.c"
#elif defined (__ADI_INT_USE_GIC__)
#include "adi_int_gic.c"
#elif defined (__ADI_INT_USE_21XXX__)
#include "adi_int_21xxx.c"
#endif


/*@}*/

