/*!
 *****************************************************************************
 * @file:    adi_sid_cm40z.h
 * @brief:   Defenition of interrupt IDs using which application/drivers
             register/unregister interrupt handlers.
 * @version: $Revision: 30871 $
 * @date:    $Date: 2015-05-01 13:22:40 -0400 (Fri, 01 May 2015) $
 *-----------------------------------------------------------------------------
 *
Copyright (c) 2010 Analog Devices, Inc.

All rights reserved.

Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:
  - Redistributions of source code must retain the above copyright notice,
    this list of conditions and the following disclaimer.
  - Redistributions in binary form must reproduce the above copyright notice,
    this list of conditions and the following disclaimer in the documentation
    and/or other materials provided with the distribution.
  - Modified versions of the software must be conspicuously marked as such.
  - This software is licensed solely and exclusively for use with processors
    manufactured by or for Analog Devices, Inc.
  - This software may not be combined or merged with other code in any manner
    that would cause the software to become subject to terms and conditions
    which differ from those listed here.
  - Neither the name of Analog Devices, Inc. nor the names of its
    contributors may be used to endorse or promote products derived
    from this software without specific prior written permission.
  - The use of this software may or may not infringe the patent rights of one
    or more patent holders.  This license does not release you from the
    requirement that you obtain separate licenses from these patent holders
    to use this software.

THIS SOFTWARE IS PROVIDED BY ANALOG DEVICES, INC. AND CONTRIBUTORS "AS IS" AND ANY
EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, NON-INFRINGEMENT,
TITLE, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN
NO EVENT SHALL ANALOG DEVICES, INC. OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, PUNITIVE OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, DAMAGES ARISING OUT OF CLAIMS OF INTELLECTUAL
PROPERTY RIGHTS INFRINGEMENT; PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

**********************************************************************************/


/* Cortex-M4 processor exceptions */
#define ADI_INT_RESET                     -15  // Reset Interrupt
#define ADI_INT_NMI                       -14  // Non Maskable Interrupt
#define ADI_INT_HARD_FAULT                -13  // Hard Fault Interrupt
#define ADI_INT_MEM_MGMT                  -12  // Memory Management Interrupt
#define ADI_INT_BUS_FAULT                 -11  // Bus Fault Interrupt
#define ADI_INT_USAGE_FAULT               -10  // Usage Fault Interrupt
//                                         -9     Reserved
//                                         -8     Reserved
//                                         -7     Reserved
//                                         -6     Reserved
#define ADI_INT_SVCALL                     -5  // System Service Call Interrupt
#define ADI_INT_DEBUG_MON                  -4  // Debug Monitor Interrupt
//                                         -3     Reserved
#define ADI_INT_PENDSV                     -2  // Pendable request for system device Interrupt
#define ADI_INT_SYSTICK                    -1  // System Tick Interrupt


/* ADSP-CM41x M4 Specific Interrupts */
#define ADI_INT_VMU0_VDDINT_EVT             0  /*!< Internal voltage management fault */
#define ADI_INT_VMU0_VDDEXT_EVT             1  /*!< External voltage management fault */
#define ADI_INT_CGU0_ERR                    2  /*!< Error */
#define ADI_INT_CGU0_OSCW_INT               3  /*!< Oscillator Watchdog Interrupt */
#define ADI_INT_OCU0_ERR                    4  /*!< Freq. out-of-range, or dead clock, or counter overflow detected */
#define ADI_INT_M4P_BCODE_ERR               5  /*!< Boot Code CRC Error */
#define ADI_INT_CTI0_EVT0                   6  /*!< Cross Trigger Interface Event 0 */
#define ADI_INT_CTI0_EVT1                   7  /*!< Cross Trigger Interface Event 1 */
#define ADI_INT_CTI0_EVT2                   8  /*!< Cross Trigger Interface Event 2 */
#define ADI_INT_M4P_LOCKUP                  9  /*!< Lockup Error (Fault only; not an interrupt) */
#define ADI_INT_M4P_BUS_FAULT              10  /*!< Bus Fault */
#define ADI_INT_M0P_LOCKUP                 11  /*!< m0 supervisor lockup error */
#define ADI_INT_SPU1_TIMEOUT               12  /*!< Timeout Interrupt */
#define ADI_INT_C1_BUS_TIMEOUT             13  /*!< Bus Timeout */
#define ADI_INT_M4P_CORE_SRAM_EERR         14  /*!< SRAM Core ECC Error */
#define ADI_INT_M4P_DMA_SRAM_EERR          15  /*!< SRAM DMA ECC Error */
#define ADI_INT_FLC0_CORE_FLASH_EERR_IRQn  16  /*!< Flash Core ECC Error */
#define ADI_INT_FLC0_DMA_FLASH_EERR_IRQn   17  /*!< Flash DMA ECC Error */
#define ADI_INT_FLC0_FLASH_EVT             18  /*!< Flash Event */
#define ADI_INT_M0P_SRAM_EERR              19  /*!< supervisor sram ecc error */
#define ADI_INT_MBOX0_PORT1_EERR           20  /*!< Port 1 ECC error */
#define ADI_INT_MBOX0_PORT0_EERR           21  /*!< Port 0 ECC error */
#define ADI_INT_FFTB0_SPERR                22  /*!< Setup parity error */
#define ADI_INT_FFTB0_DPERR                23  /*!< Data parity error */
#define ADI_INT_HAE0_PERR                  24  /*!< Parity Error */
#define ADI_INT_CSTF0_PERR                 25  /*!< Parity Error Detected */
#define ADI_INT_EFS0_EERR                  26  /*!< Reserved */
#define ADI_INT_SPU0_TIMEOUT               27  /*!< Timeout Interrupt */
#define ADI_INT_C0_BUS_TIMEOUT             28  /*!< Bus Timeout */
#define ADI_INT_C0_POSTWR_ERR              29  /*!< Posted Write Error */
#define ADI_INT_CGU0_EVT                   30  /*!< Event */
#define ADI_INT_DPM0_EVT                   31  /*!< Event */
#define ADI_INT_SEC1_ERR                   32  /*!< Error */
#define ADI_INT_SEC0_ERR                   33  /*!< Error */
#define ADI_INT_WDOG1_EXP                  34  /*!< Expiration */
#define ADI_INT_WDOG0_EXP                  35  /*!< Expiration */
#define ADI_INT_TAPC_KEYFAIL               36  /*!< User Key Fail Interrupt */
#define ADI_INT_SYS_AFE_NOTOK              37  /*!< AFE is functioning normally */
#define ADI_INT_SYS_AFE_LIMIT              38  /*!< AFE FOCP Limit Detection */
#define ADI_INT_PWM0_TRIP                  39  /*!< Trip */
#define ADI_INT_PWM1_TRIP                  40  /*!< Trip */
#define ADI_INT_PWM2_TRIP                  41  /*!< Trip */
#define ADI_INT_SMPU1_ERR                  42  /*!< Error Interrupt */
#define ADI_INT_SMPU2_ERR                  43  /*!< Error Interrupt */
#define ADI_INT_SMPU0_ERR                  44  /*!< Error Interrupt */
#define ADI_INT_SPU1_INT                   45  /*!< Interrupt */
#define ADI_INT_SPU0_INT                   46  /*!< Interrupt */
#define ADI_INT_SWU2_EVT                   47  /*!< Event */
#define ADI_INT_SWU3_EVT                   48  /*!< Event */
#define ADI_INT_SWU4_EVT                   49  /*!< Event */
#define ADI_INT_SWU5_EVT                   50  /*!< Event */
#define ADI_INT_SWU6_EVT                   51  /*!< Event */
#define ADI_INT_SWU0_EVT                   52  /*!< Event */
#define ADI_INT_SWU1_EVT                   53  /*!< Event */
#define ADI_INT_CPTMR0_CPT0_ERR            54  /*!< CPT 0 Error Interrupt */
#define ADI_INT_CPTMR0_CPT1_ERR            55  /*!< CPT 1 Error Interrupt */
#define ADI_INT_CPTMR0_CPT2_ERR            56  /*!< CPT 2 Error Interrupt */
#define ADI_INT_CRC0_ERR                   57  /*!< Error */
#define ADI_INT_SPI1_ERR                   58  /*!< Error */
#define ADI_INT_SPI0_ERR                   59  /*!< Error */
#define ADI_INT_FFTB0_LIMERR               60  /*!< Over limit error */
#define ADI_INT_MATH0_MSTAT                61  /*!< MATH unit Accumulate Interrupt Status */
#define ADI_INT_ADCC1_ERR                  62  /*!< ADC Error */
#define ADI_INT_DACC0_ERR                  63  /*!< DAC Error */
#define ADI_INT_ADCC0_ERR                  64  /*!< ADC Error */
#define ADI_INT_DMA4_ERR                   65  /*!< Error interrupt */
#define ADI_INT_DMA5_ERR                   66  /*!< Error interrupt */
#define ADI_INT_DMA6_ERR                   67  /*!< Error interrupt */
#define ADI_INT_DMA7_ERR                   68  /*!< Error interrupt */
#define ADI_INT_DMA8_ERR                   69  /*!< Error interrupt */
#define ADI_INT_DMA9_ERR                   70  /*!< Error interrupt */
#define ADI_INT_DMA10_ERR                  71  /*!< Error interrupt */
#define ADI_INT_DMA11_ERR                  72  /*!< Error interrupt */
#define ADI_INT_DMA12_ERR                  73  /*!< Error interrupt */
#define ADI_INT_DMA13_ERR                  74  /*!< Error interrupt */
#define ADI_INT_DMA0_ERR                   75  /*!< Error interrupt */
#define ADI_INT_DMA1_ERR                   76  /*!< Error interrupt */
#define ADI_INT_DMA2_ERR                   77  /*!< Error interrupt */
#define ADI_INT_DMA3_ERR                   78  /*!< Error interrupt */
#define ADI_INT_PWM0_SYNC                  79  /*!< PWMTMR Grouped */
#define ADI_INT_PWM1_SYNC                  80  /*!< PWMTMR Grouped */
#define ADI_INT_PWM2_SYNC                  81  /*!< PWMTMR Grouped */
#define ADI_INT_PINT1_BLOCK                82  /*!< Pin Interrupt Block */
#define ADI_INT_PINT2_BLOCK                83  /*!< Pin Interrupt Block */
#define ADI_INT_PINT3_BLOCK                84  /*!< Pin Interrupt Block */
#define ADI_INT_PINT4_BLOCK                85  /*!< Pin Interrupt Block */
#define ADI_INT_PINT5_BLOCK                86  /*!< Pin Interrupt Block */
#define ADI_INT_PINT0_BLOCK                87  /*!< Pin Interrupt Block */
#define ADI_INT_TIMER1_TMR0                88  /*!< Timer 0 */
#define ADI_INT_TIMER1_TMR1                89  /*!< Timer 1 */
#define ADI_INT_TIMER1_TMR2                90  /*!< Timer 2 */
#define ADI_INT_TIMER1_TMR3                91  /*!< Timer 3 */
#define ADI_INT_TIMER1_TMR4                92  /*!< Timer 4 */
#define ADI_INT_TIMER1_TMR5                93  /*!< Timer 5 */
#define ADI_INT_TIMER1_TMR6                94  /*!< Timer 6 */
#define ADI_INT_TIMER1_TMR7                95  /*!< Timer 7 */
#define ADI_INT_TIMER0_TMR0                96  /*!< Timer 0 */
#define ADI_INT_TIMER0_TMR1                97  /*!< Timer 1 */
#define ADI_INT_TIMER0_TMR2                98  /*!< Timer 2 */
#define ADI_INT_TIMER0_TMR3                99  /*!< Timer 3 */
#define ADI_INT_TIMER0_TMR4               100  /*!< Timer 4 */
#define ADI_INT_TIMER0_TMR5               101  /*!< Timer 5 */
#define ADI_INT_TIMER0_TMR6               102  /*!< Timer 6 */
#define ADI_INT_TIMER0_TMR7               103  /*!< Timer 7 */
#define ADI_INT_TIMER1_STAT               104  /*!< Status */
#define ADI_INT_TIMER0_STAT               105  /*!< Status */
#define ADI_INT_CPTMR0_CPT0_MEAS          106  /*!< CPT 0 Measure Interrupt */
#define ADI_INT_CPTMR0_CPT1_MEAS          107  /*!< CPT 1 Measure Interrupt */
#define ADI_INT_CPTMR0_CPT2_MEAS          108  /*!< CPT 2 Measure Interrupt */
#define ADI_INT_DMA4_INT                  109  /*!< Done interrupt */
#define ADI_INT_DMA5_INT                  110  /*!< Done interrupt */
#define ADI_INT_DMA6_INT                  111  /*!< Done interrupt */
#define ADI_INT_DMA7_INT                  112  /*!< Done interrupt */
#define ADI_INT_DMA8_INT                  113  /*!< Done interrupt */
#define ADI_INT_DMA9_INT                  114  /*!< Done interrupt */
#define ADI_INT_DMA10_INT                 115  /*!< Done interrupt */
#define ADI_INT_DMA11_INT                 116  /*!< Done interrupt */
#define ADI_INT_DMA12_INT                 117  /*!< Done interrupt */
#define ADI_INT_DMA13_INT                 118  /*!< Done interrupt */
#define ADI_INT_DMA0_INT                  119  /*!< Done interrupt */
#define ADI_INT_DMA1_INT                  120  /*!< Done interrupt */
#define ADI_INT_DMA2_INT                  121  /*!< Done interrupt */
#define ADI_INT_DMA3_INT                  122  /*!< Done interrupt */
#define ADI_INT_TRU1_INT0                 123  /*!< Interrupt request 0 */
#define ADI_INT_TRU1_INT1                 124  /*!< Interrupt request 1 */
#define ADI_INT_TRU1_INT2                 125  /*!< Interrupt request 2 */
#define ADI_INT_TRU1_INT3                 126  /*!< Interrupt request 3 */
#define ADI_INT_TRU0_INT0                 127  /*!< Interrupt request 0 */
#define ADI_INT_FFTB0_DONE                128  /*!< FFT done */
#define ADI_INT_ADCC1_TMR0_EVT            129  /*!< Timer 0 Event Complete */
#define ADI_INT_ADCC1_TMR1_EVT            130  /*!< Timer 1 Event Complete */
#define ADI_INT_ADCC0_TMR0_EVT            131  /*!< Timer 0 Event Complete */
#define ADI_INT_ADCC0_TMR1_EVT            132  /*!< Timer 1 Event Complete */
#define ADI_INT_DACC0_DAC0                133  /*!< DAC Interrupt 0 */
#define ADI_INT_DACC0_DAC1                134  /*!< DAC Interrupt 1 */
#define ADI_INT_SPI1_STAT                 135  /*!< Status */
#define ADI_INT_SPI0_STAT                 136  /*!< Status */
#define ADI_INT_SPORT0_A_STAT             137  /*!< Channel A Status */
#define ADI_INT_SPORT0_B_STAT             138  /*!< Channel B Status */
#define ADI_INT_UART1_STAT                139  /*!< Status */
#define ADI_INT_UART2_STAT                140  /*!< Status */
#define ADI_INT_UART3_STAT                141  /*!< Status */
#define ADI_INT_UART4_STAT                142  /*!< Status */
#define ADI_INT_UART0_STAT                143  /*!< Status */
#define ADI_INT_HAE0_STAT                 144  /*!< Status */
#define ADI_INT_CRC0_DCNTEXP              145  /*!< Data count expiration */
#define ADI_INT_CAN1_TX                   146  /*!< Transmit */
#define ADI_INT_CAN1_RX                   147  /*!< Receive */
#define ADI_INT_CAN1_STAT                 148  /*!< Status */
#define ADI_INT_CAN0_TX                   149  /*!< Transmit */
#define ADI_INT_CAN0_RX                   150  /*!< Receive */
#define ADI_INT_CAN0_STAT                 151  /*!< Status */
#define ADI_INT_CNT0_STAT                 152  /*!< Status */
#define ADI_INT_SINC0_STAT                153  /*!< Status */
#define ADI_INT_TWI0_DATA                 154  /*!< Data Interrupt */
#define ADI_INT_MBOX0_PORT1_MSG           155  /*!< Port 1 software interrupt */
#define ADI_INT_MBOX0_PORT0_MSG           156  /*!< Port 0 software interrupt */
#define ADI_INT_LBA0_SYS_OUT0             157  /*!< Registered LBA outputs available to system */
#define ADI_INT_M4P_SOFT_INT0             158  /*!< Software Interrupt 0 */
#define ADI_INT_M4P_SOFT_INT1             159  /*!< Software Interrupt 1 */
#define ADI_INT_M4P_SOFT_INT2             160  /*!< Software Interrupt 2 */
#define ADI_INT_M4P_SOFT_INT3             161  /*!< Software Interrupt 3 */
#define ADI_INT_M4P_SOFT_INT4             162  /*!< Software Interrupt 4 */
#define ADI_INT_M4P_SOFT_INT5             163  /*!< Software Interrupt 5 */

/* Update this based on the number of interrupts */
#define ADI_INT_NUM_INT         164          /* Number of Interrupts */

