/*!
 *****************************************************************************
 * @file:    startup.c
 * @brief:   Interrupt table and default handlers for ADSP-CM41x for M4 Core
 * @version: $Revision: 31163 $
 * @date:    $Date: 2015-05-20 13:37:21 -0400 (Wed, 20 May 2015) $
 *-----------------------------------------------------------------------------
 *
Copyright (c) 2010 Analog Devices, Inc.

All rights reserved.

Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:
  - Redistributions of source code must retain the above copyright notice,
    this list of conditions and the following disclaimer.
  - Redistributions in binary form must reproduce the above copyright notice,
    this list of conditions and the following disclaimer in the documentation
    and/or other materials provided with the distribution.
  - Modified versions of the software must be conspicuously marked as such.
  - This software is licensed solely and exclusively for use with processors
    manufactured by or for Analog Devices, Inc.
  - This software may not be combined or merged with other code in any manner
    that would cause the software to become subject to terms and conditions
    which differ from those listed here.
  - Neither the name of Analog Devices, Inc. nor the names of its
    contributors may be used to endorse or promote products derived
    from this software without specific prior written permission.
  - The use of this software may or may not infringe the patent rights of one
    or more patent holders.  This license does not release you from the
    requirement that you obtain separate licenses from these patent holders
    to use this software.

THIS SOFTWARE IS PROVIDED BY ANALOG DEVICES, INC. AND CONTRIBUTORS "AS IS" AND ANY
EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, NON-INFRINGEMENT,
TITLE, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN
NO EVENT SHALL ANALOG DEVICES, INC. OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, PUNITIVE OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, DAMAGES ARISING OUT OF CLAIMS OF INTELLECTUAL
PROPERTY RIGHTS INFRINGEMENT; PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 *****************************************************************************/

#include "startup.h"

#ifdef ADI_MT_SUPPORT
/*
 * Micrium uCOS-III redefines these handler names.  If the application
 * uses uCOS-III the macro ADI_MT_SUPPORT must be added to the project
 * preprocessor options.
 */
#define PendSV_Handler  OS_CPU_PendSVHandler
#define SysTick_Handler OS_CPU_SysTickHandler
#endif

//*****************************************************************************
//
// Local helpers for consistent ISR prototypes and implementations.
//
//*****************************************************************************
#define WEAK_PROTOTYPE(x) WEAK_PROTO ( void x (void)) ATTRIBUTE_INTERRUPT ;

#ifdef HANDLERS_IN_FLASH
// Locate the handlers in flash. The default linker .icf file copies "ro" code
// to RAM. To place the handlers in flash the .icf file must be modified to
// not copy "ro" code:
//   initialize by copy { rw };
#define WEAK_FUNCTION(x)  WEAK_FUNC  ( void x (void)) { while(1); }
#else
// Note: because the reset handler (ResetISR) is where the startup lives,
// the linker can't to initialize it because its needed for startup.  That
// causes the linker to mark the entire module as un-initializable and would
// result in all handlers being located in flash (along with the reset vector).
// Marking the bulk of the interrupt handlers as "__ramfunc" tells the linker
// its OK to locate them in RAM as part of the initialization process.  It
// puts them into a special ".textrw" section which is placed explicitly
// into the RAM_CODE region by the icf file (in addition to ".text").
#define WEAK_FUNCTION(x)  WEAK_FUNC  ( __ramfunc void x (void)) { while(1); }
#endif

//*****************************************************************************
//
// Forward declaration of implimented exception handlers.
//
//*****************************************************************************
WEAK_PROTOTYPE( ResetISR                           )
WEAK_PROTOTYPE( NmiSR                              )
WEAK_PROTOTYPE( HardFault_Handler                  )
WEAK_PROTOTYPE( MemManage_Handler                  )
WEAK_PROTOTYPE( BusFault_Handler                   )
WEAK_PROTOTYPE( UsageFault_Handler                 )
WEAK_PROTOTYPE( SVC_Handler                        )
WEAK_PROTOTYPE( DebugMon_Handler                   )
WEAK_PROTOTYPE( PendSV_Handler                     )
WEAK_PROTOTYPE( SysTick_Handler                    )

//*****************************************************************************
//
// Forward declaration of the programmable device interrupt handlers.
//
//*****************************************************************************
WEAK_PROTOTYPE( VMU0_VDDINT_EVT_Handler            )
WEAK_PROTOTYPE( VMU0_VDDEXT_EVT_Handler            )
WEAK_PROTOTYPE( CGU0_ERR_Handler                   )
WEAK_PROTOTYPE( CGU0_OSCW_INT_Handler              )
WEAK_PROTOTYPE( OCU0_ERR_Handler                   )
WEAK_PROTOTYPE( M4P_BCODE_ERR_Handler              )
WEAK_PROTOTYPE( CTI0_EVT0_Handler                  )
WEAK_PROTOTYPE( CTI0_EVT1_Handler                  )
WEAK_PROTOTYPE( CTI0_EVT2_Handler                  )
WEAK_PROTOTYPE( M4P_LOCKUP_Handler                 )
WEAK_PROTOTYPE( M4P_BUS_FAULT_Handler              )
WEAK_PROTOTYPE( M0P_LOCKUP_Handler                 )
WEAK_PROTOTYPE( SPU1_TIMEOUT_Handler               )
WEAK_PROTOTYPE( C1_BUS_TIMEOUT_Handler             )
WEAK_PROTOTYPE( M4P_CORE_SRAM_EERR_Handler         )
WEAK_PROTOTYPE( M4P_DMA_SRAM_EERR_Handler          )
WEAK_PROTOTYPE( FLC0_CORE_FLASH_EERR_Handler       )
WEAK_PROTOTYPE( FLC0_DMA_FLASH_EERR_Handler        )
WEAK_PROTOTYPE( FLC0_FLASH_EVT_Handler             )
WEAK_PROTOTYPE( M0P_SRAM_EERR_Handler              )
WEAK_PROTOTYPE( MBOX0_PORT1_EERR_Handler           )
WEAK_PROTOTYPE( MBOX0_PORT0_EERR_Handler           )
WEAK_PROTOTYPE( FFTB0_SPERR_Handler                )
WEAK_PROTOTYPE( FFTB0_DPERR_Handler                )
WEAK_PROTOTYPE( HAE0_PERR_Handler                  )
WEAK_PROTOTYPE( CSTF0_PERR_Handler                 )
WEAK_PROTOTYPE( RESERVED_VECTOR                    )
WEAK_PROTOTYPE( SPU0_TIMEOUT_Handler               )
WEAK_PROTOTYPE( C0_BUS_TIMEOUT_Handler             )
WEAK_PROTOTYPE( C0_POSTWR_ERR_Handler              )
WEAK_PROTOTYPE( CGU0_EVT_Handler                   )
WEAK_PROTOTYPE( DPM0_EVT_Handler                   )
WEAK_PROTOTYPE( SEC1_ERR_Handler                   )
WEAK_PROTOTYPE( SEC0_ERR_Handler                   )
WEAK_PROTOTYPE( WDOG1_EXP_Handler                  )
WEAK_PROTOTYPE( WDOG0_EXP_Handler                  )
WEAK_PROTOTYPE( TAPC_KEYFAIL_Handler               )
WEAK_PROTOTYPE( AFE_NOTOK_Handler                  )
WEAK_PROTOTYPE( AFE_LIMIT_Handler                  )
WEAK_PROTOTYPE( PWM0_TRIP_Handler                  )
WEAK_PROTOTYPE( PWM1_TRIP_Handler                  )
WEAK_PROTOTYPE( PWM2_TRIP_Handler                  )
WEAK_PROTOTYPE( SMPU1_ERR_Handler                  )
WEAK_PROTOTYPE( SMPU2_ERR_Handler                  )
WEAK_PROTOTYPE( SMPU0_ERR_Handler                  )
WEAK_PROTOTYPE( SPU1_INT_Handler                   )
WEAK_PROTOTYPE( SPU0_INT_Handler                   )
WEAK_PROTOTYPE( SWU2_EVT_Handler                   )
WEAK_PROTOTYPE( SWU3_EVT_Handler                   )
WEAK_PROTOTYPE( SWU4_EVT_Handler                   )
WEAK_PROTOTYPE( SWU5_EVT_Handler                   )
WEAK_PROTOTYPE( SWU6_EVT_Handler                   )
WEAK_PROTOTYPE( SWU0_EVT_Handler                   )
WEAK_PROTOTYPE( SWU1_EVT_Handler                   )
WEAK_PROTOTYPE( CPTMR0_CPT0_ERR_Handler            )
WEAK_PROTOTYPE( CPTMR0_CPT1_ERR_Handler            )
WEAK_PROTOTYPE( CPTMR0_CPT2_ERR_Handler            )
WEAK_PROTOTYPE( CRC0_ERR_Handler                   )
WEAK_PROTOTYPE( SPI1_ERR_Handler                   )
WEAK_PROTOTYPE( SPI0_ERR_Handler                   )
WEAK_PROTOTYPE( FFTB0_LIMERR_Handler               )
WEAK_PROTOTYPE( MATH0_MSTAT_Handler                )
WEAK_PROTOTYPE( ADCC1_ERR_Handler                  )
WEAK_PROTOTYPE( DACC0_ERR_Handler                  )
WEAK_PROTOTYPE( ADCC0_ERR_Handler                  )
WEAK_PROTOTYPE( DMA4_ERR_Handler                   )
WEAK_PROTOTYPE( DMA5_ERR_Handler                   )
WEAK_PROTOTYPE( DMA6_ERR_Handler                   )
WEAK_PROTOTYPE( DMA7_ERR_Handler                   )
WEAK_PROTOTYPE( DMA8_ERR_Handler                   )
WEAK_PROTOTYPE( DMA9_ERR_Handler                   )
WEAK_PROTOTYPE( DMA10_ERR_Handler                  )
WEAK_PROTOTYPE( DMA11_ERR_Handler                  )
WEAK_PROTOTYPE( DMA12_ERR_Handler                  )
WEAK_PROTOTYPE( DMA13_ERR_Handler                  )
WEAK_PROTOTYPE( DMA0_ERR_Handler                   )
WEAK_PROTOTYPE( DMA1_ERR_Handler                   )
WEAK_PROTOTYPE( DMA2_ERR_Handler                   )
WEAK_PROTOTYPE( DMA3_ERR_Handler                   )
WEAK_PROTOTYPE( PWM0_SYNC_Handler                  )
WEAK_PROTOTYPE( PWM1_SYNC_Handler                  )
WEAK_PROTOTYPE( PWM2_SYNC_Handler                  )
WEAK_PROTOTYPE( PINT1_BLOCK_Handler                )
WEAK_PROTOTYPE( PINT2_BLOCK_Handler                )
WEAK_PROTOTYPE( PINT3_BLOCK_Handler                )
WEAK_PROTOTYPE( PINT4_BLOCK_Handler                )
WEAK_PROTOTYPE( PINT5_BLOCK_Handler                )
WEAK_PROTOTYPE( PINT0_BLOCK_Handler                )
WEAK_PROTOTYPE( TIMER1_TMR0_Handler                )
WEAK_PROTOTYPE( TIMER1_TMR1_Handler                )
WEAK_PROTOTYPE( TIMER1_TMR2_Handler                )
WEAK_PROTOTYPE( TIMER1_TMR3_Handler                )
WEAK_PROTOTYPE( TIMER1_TMR4_Handler                )
WEAK_PROTOTYPE( TIMER1_TMR5_Handler                )
WEAK_PROTOTYPE( TIMER1_TMR6_Handler                )
WEAK_PROTOTYPE( TIMER1_TMR7_Handler                )
WEAK_PROTOTYPE( TIMER0_TMR0_Handler                )
WEAK_PROTOTYPE( TIMER0_TMR1_Handler                )
WEAK_PROTOTYPE( TIMER0_TMR2_Handler                )
WEAK_PROTOTYPE( TIMER0_TMR3_Handler                )
WEAK_PROTOTYPE( TIMER0_TMR4_Handler                )
WEAK_PROTOTYPE( TIMER0_TMR5_Handler                )
WEAK_PROTOTYPE( TIMER0_TMR6_Handler                )
WEAK_PROTOTYPE( TIMER0_TMR7_Handler                )
WEAK_PROTOTYPE( TIMER1_STAT_Handler                )
WEAK_PROTOTYPE( TIMER0_STAT_Handler                )
WEAK_PROTOTYPE( CPTMR0_CPT0_MEAS_Handler           )
WEAK_PROTOTYPE( CPTMR0_CPT1_MEAS_Handler           )
WEAK_PROTOTYPE( CPTMR0_CPT2_MEAS_Handler           )
WEAK_PROTOTYPE( DMA4_INT_Handler                   )
WEAK_PROTOTYPE( DMA5_INT_Handler                   )
WEAK_PROTOTYPE( DMA6_INT_Handler                   )
WEAK_PROTOTYPE( DMA7_INT_Handler                   )
WEAK_PROTOTYPE( DMA8_INT_Handler                   )
WEAK_PROTOTYPE( DMA9_INT_Handler                   )
WEAK_PROTOTYPE( DMA10_INT_Handler                  )
WEAK_PROTOTYPE( DMA11_INT_Handler                  )
WEAK_PROTOTYPE( DMA12_INT_Handler                  )
WEAK_PROTOTYPE( DMA13_INT_Handler                  )
WEAK_PROTOTYPE( DMA0_INT_Handler                   )
WEAK_PROTOTYPE( DMA1_INT_Handler                   )
WEAK_PROTOTYPE( DMA2_INT_Handler                   )
WEAK_PROTOTYPE( DMA3_INT_Handler                   )
WEAK_PROTOTYPE( TRU1_INT0_Handler                  )
WEAK_PROTOTYPE( TRU1_INT1_Handler                  )
WEAK_PROTOTYPE( TRU1_INT2_Handler                  )
WEAK_PROTOTYPE( TRU1_INT3_Handler                  )
WEAK_PROTOTYPE( TRU0_INT0_Handler                  )
WEAK_PROTOTYPE( FFTB0_DONE_Handler                 )
WEAK_PROTOTYPE( ADCC1_TMR0_EVT_Handler             )
WEAK_PROTOTYPE( ADCC1_TMR1_EVT_Handler             )
WEAK_PROTOTYPE( ADCC0_TMR0_EVT_Handler             )
WEAK_PROTOTYPE( ADCC0_TMR1_EVT_Handler             )
WEAK_PROTOTYPE( DACC0_DAC0_Handler                 )
WEAK_PROTOTYPE( DACC0_DAC1_Handler                 )
WEAK_PROTOTYPE( SPI1_STAT_Handler                  )
WEAK_PROTOTYPE( SPI0_STAT_Handler                  )
WEAK_PROTOTYPE( SPORT0_A_STAT_Handler              )
WEAK_PROTOTYPE( SPORT0_B_STAT_Handler              )
WEAK_PROTOTYPE( UART1_STAT_Handler                 )
WEAK_PROTOTYPE( UART2_STAT_Handler                 )
WEAK_PROTOTYPE( UART3_STAT_Handler                 )
WEAK_PROTOTYPE( UART4_STAT_Handler                 )
WEAK_PROTOTYPE( UART0_STAT_Handler                 )
WEAK_PROTOTYPE( HAE0_STAT_Handler                  )
WEAK_PROTOTYPE( CRC0_DCNTEXP_Handler               )
WEAK_PROTOTYPE( CAN1_TX_Handler                    )
WEAK_PROTOTYPE( CAN1_RX_Handler                    )
WEAK_PROTOTYPE( CAN1_STAT_Handler                  )
WEAK_PROTOTYPE( CAN0_TX_Handler                    )
WEAK_PROTOTYPE( CAN0_RX_Handler                    )
WEAK_PROTOTYPE( CAN0_STAT_Handler                  )
WEAK_PROTOTYPE( CNT0_STAT_Handler                  )
WEAK_PROTOTYPE( SINC0_STAT_Handler                 )
WEAK_PROTOTYPE( TWI0_DATA_Handler                  )
WEAK_PROTOTYPE( MBOX0_PORT1_MSG_Handler            )
WEAK_PROTOTYPE( MBOX0_PORT0_MSG_Handler            )
WEAK_PROTOTYPE( LBA0_SYS_OUT0_Handler              )
WEAK_PROTOTYPE( M4P_SOFT_INT0_Handler              )
WEAK_PROTOTYPE( M4P_SOFT_INT1_Handler              )
WEAK_PROTOTYPE( M4P_SOFT_INT2_Handler              )
WEAK_PROTOTYPE( M4P_SOFT_INT3_Handler              )
WEAK_PROTOTYPE( M4P_SOFT_INT4_Handler              )
WEAK_PROTOTYPE( M4P_SOFT_INT5_Handler              )
WEAK_PROTOTYPE( RESERVED_VECTOR                    )


/*
    Stack size considerations for RTOS environments:

    In the Cortex-M class processors, the hardware has two stacks: the main stack
    and the process stack.  The main stack is used at reset and by system exception
    handlers.  In simple applications (non-RTOS) you may only use this stack.  In
    more complex systems that use an RTOS you have a split between the main stack
    which is used by the kernel and exception handlers and the process stack which
    is used by the tasks and programmable interrupts (interrupts stack on top of
    the currently active task, so tasks stacks should be allocated for worst-case
    interrupt scenarios).  In the uCOS case, the process stack is the one that gets
    context-switched and used by the tasks, where we store the registers, etc.

    As RTOS tasks specify their own stack area, a minimal size of 4 for the process
    stack in order to retain symbols, etc., seems OK and we would not need any more.
    The main stack needs to be big enough to initialize the RTOS, run interrupts etc.

    As always, stack and heap size optimizations is a balancing act between usage
    and available memory.  It is entirely application-dependant.

*/


// IVT typedefs
typedef void  ( *IntFunc )( void );
typedef union { IntFunc __fun; void * __ptr; } IntVector;

// import linker symbol
#pragma segment="CSTACK"

// Interrupt Vector Table
#pragma location = ".intvec"
__root const IntVector __vector_table[] =
{
    // grab stack pointer "end" address from ICF file
    { .__ptr = __sfe( "CSTACK" ) },

// exception mappings...
    {ResetISR                           },  // -15
    {NmiSR                              },  // -14
    {HardFault_Handler                  },  // -13
    {MemManage_Handler                  },  // -12
    {BusFault_Handler                   },  // -11
    {UsageFault_Handler                 },  // -10
    {(void(*)(void))0xAD1221AD          },  // -09  Security Key for Boot ROM, formally RESERVED_VECTOR
    {RESERVED_VECTOR                    },  // -08
    {RESERVED_VECTOR                    },  // -07
    {RESERVED_VECTOR                    },  // -06
    {SVC_Handler                        },  // -05
    {DebugMon_Handler                   },  // -04
    {RESERVED_VECTOR                    },  // -03
    {PendSV_Handler                     },  // -02  (Micrium overrides weak binding if using uCOS)
    {SysTick_Handler                    },  // -01  (Micrium overrides weak binding if using uCOS)

// programmable interrupt mappings...


    {VMU0_VDDINT_EVT_Handler            },  //   0  VMU0 Internal voltage management fault
    {VMU0_VDDEXT_EVT_Handler            },  //   1  VMU0 External voltage management fault
    {CGU0_ERR_Handler                   },  //   2  CGU0 Error
    {CGU0_OSCW_INT_Handler              },  //   3  CGU0 Oscillator Watchdog Interrupt
    {OCU0_ERR_Handler                   },  //   4  OCU0 Freq. out-of-range, or dead clock, or counter overflow detected
    {M4P_BCODE_ERR_Handler              },  //   5  M4P Boot Code CRC Error
    {CTI0_EVT0_Handler                  },  //   6  CTI0 Cross Trigger Interface Event 0
    {CTI0_EVT1_Handler                  },  //   7  CTI0 Cross Trigger Interface Event 1
    {CTI0_EVT2_Handler                  },  //   8  CTI0 Cross Trigger Interface Event 2
    {M4P_LOCKUP_Handler                 },  //   9  M4P Lockup Error (Fault only; not an interrupt)
    {M4P_BUS_FAULT_Handler              },  //  10  M4P Bus Fault
    {M0P_LOCKUP_Handler                 },  //  11  M0P m0 supervisor lockup error
    {SPU1_TIMEOUT_Handler               },  //  12  SPU1 Timeout Interrupt
    {C1_BUS_TIMEOUT_Handler             },  //  13  C1 Bus Timeout
    {M4P_CORE_SRAM_EERR_Handler         },  //  14  M4P SRAM Core ECC Error
    {M4P_DMA_SRAM_EERR_Handler          },  //  15  M4P SRAM DMA ECC Error
    {FLC0_CORE_FLASH_EERR_Handler       },  //  16  FLC0 Flash Core ECC Error
    {FLC0_DMA_FLASH_EERR_Handler        },  //  17  FLC0 Flash DMA ECC Error
    {FLC0_FLASH_EVT_Handler             },  //  18  FLC0 Flash Event
    {M0P_SRAM_EERR_Handler              },  //  19  M0P supervisor sram ecc error
    {MBOX0_PORT1_EERR_Handler           },  //  20  MBOX0 Port 1 ECC error
    {MBOX0_PORT0_EERR_Handler           },  //  21  MBOX0 Port 0 ECC error
    {FFTB0_SPERR_Handler                },  //  22  FFTB0 Setup parity error
    {FFTB0_DPERR_Handler                },  //  23  FFTB0 Data parity error
    {HAE0_PERR_Handler                  },  //  24  HAE0 Parity Error
    {CSTF0_PERR_Handler                 },  //  25  CSTF0 Parity Error Detected
    {RESERVED_VECTOR                    },  //  26  EFS0 Reserved
    {SPU0_TIMEOUT_Handler               },  //  27  SPU0 Timeout Interrupt
    {C0_BUS_TIMEOUT_Handler             },  //  28  C0 Bus Timeout
    {C0_POSTWR_ERR_Handler              },  //  29  C0 Posted Write Error
    {CGU0_EVT_Handler                   },  //  30  CGU0 Event
    {DPM0_EVT_Handler                   },  //  31  DPM0 Event
    {SEC1_ERR_Handler                   },  //  32  SEC1 Error
    {SEC0_ERR_Handler                   },  //  33  SEC0 Error
    {WDOG1_EXP_Handler                  },  //  34  WDOG1 Expiration
    {WDOG0_EXP_Handler                  },  //  35  WDOG0 Expiration
    {TAPC_KEYFAIL_Handler               },  //  36  TAPC User Key Fail Interrupt
    {AFE_NOTOK_Handler                  },  //  37  AFE is functioning normally
    {AFE_LIMIT_Handler                  },  //  38  AFE FOCP Limit Detection
    {PWM0_TRIP_Handler                  },  //  39  PWM0 Trip
    {PWM1_TRIP_Handler                  },  //  40  PWM1 Trip
    {PWM2_TRIP_Handler                  },  //  41  PWM2 Trip
    {SMPU1_ERR_Handler                  },  //  42  SMPU1 Error Interrupt
    {SMPU2_ERR_Handler                  },  //  43  SMPU2 Error Interrupt
    {SMPU0_ERR_Handler                  },  //  44  SMPU0 Error Interrupt
    {SPU1_INT_Handler                   },  //  45  SPU1 Interrupt
    {SPU0_INT_Handler                   },  //  46  SPU0 Interrupt
    {SWU2_EVT_Handler                   },  //  47  SWU2 Event
    {SWU3_EVT_Handler                   },  //  48  SWU3 Event
    {SWU4_EVT_Handler                   },  //  49  SWU4 Event
    {SWU5_EVT_Handler                   },  //  50  SWU5 Event
    {SWU6_EVT_Handler                   },  //  51  SWU6 Event
    {SWU0_EVT_Handler                   },  //  52  SWU0 Event
    {SWU1_EVT_Handler                   },  //  53  SWU1 Event
    {CPTMR0_CPT0_ERR_Handler            },  //  54  CPTMR0 CPT 0 Error Interrupt
    {CPTMR0_CPT1_ERR_Handler            },  //  55  CPTMR0 CPT 1 Error Interrupt
    {CPTMR0_CPT2_ERR_Handler            },  //  56  CPTMR0 CPT 2 Error Interrupt
    {CRC0_ERR_Handler                   },  //  57  CRC0 Error
    {SPI1_ERR_Handler                   },  //  58  SPI1 Error
    {SPI0_ERR_Handler                   },  //  59  SPI0 Error
    {FFTB0_LIMERR_Handler               },  //  60  FFTB0 Over limit error
    {MATH0_MSTAT_Handler                },  //  61  MATH0 MATH unit Accumulate Interrupt Status
    {ADCC1_ERR_Handler                  },  //  62  ADCC1 ADC Error
    {DACC0_ERR_Handler                  },  //  63  DACC0 DAC Error
    {ADCC0_ERR_Handler                  },  //  64  ADCC0 ADC Error
    {DMA4_ERR_Handler                   },  //  65  DMA4 Error interrupt
    {DMA5_ERR_Handler                   },  //  66  DMA5 Error interrupt
    {DMA6_ERR_Handler                   },  //  67  DMA6 Error interrupt
    {DMA7_ERR_Handler                   },  //  68  DMA7 Error interrupt
    {DMA8_ERR_Handler                   },  //  69  DMA8 Error interrupt
    {DMA9_ERR_Handler                   },  //  70  DMA9 Error interrupt
    {DMA10_ERR_Handler                  },  //  71  DMA10 Error interrupt
    {DMA11_ERR_Handler                  },  //  72  DMA11 Error interrupt
    {DMA12_ERR_Handler                  },  //  73  DMA12 Error interrupt
    {DMA13_ERR_Handler                  },  //  74  DMA13 Error interrupt
    {DMA0_ERR_Handler                   },  //  75  DMA0 Error interrupt
    {DMA1_ERR_Handler                   },  //  76  DMA1 Error interrupt
    {DMA2_ERR_Handler                   },  //  77  DMA2 Error interrupt
    {DMA3_ERR_Handler                   },  //  78  DMA3 Error interrupt
    {PWM0_SYNC_Handler                  },  //  79  PWM0 PWMTMR Grouped
    {PWM1_SYNC_Handler                  },  //  80  PWM1 PWMTMR Grouped
    {PWM2_SYNC_Handler                  },  //  81  PWM2 PWMTMR Grouped
    {PINT1_BLOCK_Handler                },  //  82  PINT1 Pin Interrupt Block
    {PINT2_BLOCK_Handler                },  //  83  PINT2 Pin Interrupt Block
    {PINT3_BLOCK_Handler                },  //  84  PINT3 Pin Interrupt Block
    {PINT4_BLOCK_Handler                },  //  85  PINT4 Pin Interrupt Block
    {PINT5_BLOCK_Handler                },  //  86  PINT5 Pin Interrupt Block
    {PINT0_BLOCK_Handler                },  //  87  PINT0 Pin Interrupt Block
    {TIMER1_TMR0_Handler                },  //  88  TIMER1 Timer 0
    {TIMER1_TMR1_Handler                },  //  89  TIMER1 Timer 1
    {TIMER1_TMR2_Handler                },  //  90  TIMER1 Timer 2
    {TIMER1_TMR3_Handler                },  //  91  TIMER1 Timer 3
    {TIMER1_TMR4_Handler                },  //  92  TIMER1 Timer 4
    {TIMER1_TMR5_Handler                },  //  93  TIMER1 Timer 5
    {TIMER1_TMR6_Handler                },  //  94  TIMER1 Timer 6
    {TIMER1_TMR7_Handler                },  //  95  TIMER1 Timer 7
    {TIMER0_TMR0_Handler                },  //  96  TIMER0 Timer 0
    {TIMER0_TMR1_Handler                },  //  97  TIMER0 Timer 1
    {TIMER0_TMR2_Handler                },  //  98  TIMER0 Timer 2
    {TIMER0_TMR3_Handler                },  //  99  TIMER0 Timer 3
    {TIMER0_TMR4_Handler                },  // 100  TIMER0 Timer 4
    {TIMER0_TMR5_Handler                },  // 101  TIMER0 Timer 5
    {TIMER0_TMR6_Handler                },  // 102  TIMER0 Timer 6
    {TIMER0_TMR7_Handler                },  // 103  TIMER0 Timer 7
    {TIMER1_STAT_Handler                },  // 104  TIMER1 Status
    {TIMER0_STAT_Handler                },  // 105  TIMER0 Status
    {CPTMR0_CPT0_MEAS_Handler           },  // 106  CPTMR0 CPT 0 Measure Interrupt
    {CPTMR0_CPT1_MEAS_Handler           },  // 107  CPTMR0 CPT 1 Measure Interrupt
    {CPTMR0_CPT2_MEAS_Handler           },  // 108  CPTMR0 CPT 2 Measure Interrupt
    {DMA4_INT_Handler                   },  // 109  DMA4 Done interrupt
    {DMA5_INT_Handler                   },  // 110  DMA5 Done interrupt
    {DMA6_INT_Handler                   },  // 111  DMA6 Done interrupt
    {DMA7_INT_Handler                   },  // 112  DMA7 Done interrupt
    {DMA8_INT_Handler                   },  // 113  DMA8 Done interrupt
    {DMA9_INT_Handler                   },  // 114  DMA9 Done interrupt
    {DMA10_INT_Handler                  },  // 115  DMA10 Done interrupt
    {DMA11_INT_Handler                  },  // 116  DMA11 Done interrupt
    {DMA12_INT_Handler                  },  // 117  DMA12 Done interrupt
    {DMA13_INT_Handler                  },  // 118  DMA13 Done interrupt
    {DMA0_INT_Handler                   },  // 119  DMA0 Done interrupt
    {DMA1_INT_Handler                   },  // 120  DMA1 Done interrupt
    {DMA2_INT_Handler                   },  // 121  DMA2 Done interrupt
    {DMA3_INT_Handler                   },  // 122  DMA3 Done interrupt
    {TRU1_INT0_Handler                  },  // 123  TRU1 Interrupt request 0
    {TRU1_INT1_Handler                  },  // 124  TRU1 Interrupt request 1
    {TRU1_INT2_Handler                  },  // 125  TRU1 Interrupt request 2
    {TRU1_INT3_Handler                  },  // 126  TRU1 Interrupt request 3
    {TRU0_INT0_Handler                  },  // 127  TRU0 Interrupt request 0
    {FFTB0_DONE_Handler                 },  // 128  FFTB0 FFT done
    {ADCC1_TMR0_EVT_Handler             },  // 129  ADCC1 Timer 0 Event Complete
    {ADCC1_TMR1_EVT_Handler             },  // 130  ADCC1 Timer 1 Event Complete
    {ADCC0_TMR0_EVT_Handler             },  // 131  ADCC0 Timer 0 Event Complete
    {ADCC0_TMR1_EVT_Handler             },  // 132  ADCC0 Timer 1 Event Complete
    {DACC0_DAC0_Handler                 },  // 133  DACC0 DAC Interrupt 0
    {DACC0_DAC1_Handler                 },  // 134  DACC0 DAC Interrupt 1
    {SPI1_STAT_Handler                  },  // 135  SPI1 Status
    {SPI0_STAT_Handler                  },  // 136  SPI0 Status
    {SPORT0_A_STAT_Handler              },  // 137  SPORT0 Channel A Status
    {SPORT0_B_STAT_Handler              },  // 138  SPORT0 Channel B Status
    {UART1_STAT_Handler                 },  // 139  UART1 Status
    {UART2_STAT_Handler                 },  // 140  UART2 Status
    {UART3_STAT_Handler                 },  // 141  UART3 Status
    {UART4_STAT_Handler                 },  // 142  UART4 Status
    {UART0_STAT_Handler                 },  // 143  UART0 Status
    {HAE0_STAT_Handler                  },  // 144  HAE0 Status
    {CRC0_DCNTEXP_Handler               },  // 145  CRC0 Data count expiration
    {CAN1_TX_Handler                    },  // 146  CAN1 Transmit
    {CAN1_RX_Handler                    },  // 147  CAN1 Receive
    {CAN1_STAT_Handler                  },  // 148  CAN1 Status
    {CAN0_TX_Handler                    },  // 149  CAN0 Transmit
    {CAN0_RX_Handler                    },  // 150  CAN0 Receive
    {CAN0_STAT_Handler                  },  // 151  CAN0 Status
    {CNT0_STAT_Handler                  },  // 152  CNT0 Status
    {SINC0_STAT_Handler                 },  // 153  SINC0 Status
    {TWI0_DATA_Handler                  },  // 154  TWI0 Data Interrupt
    {MBOX0_PORT1_MSG_Handler            },  // 155  MBOX0 Port 1 software interrupt
    {MBOX0_PORT0_MSG_Handler            },  // 156  MBOX0 Port 0 software interrupt
    {LBA0_SYS_OUT0_Handler              },  // 157  LBA0 Registered LBA outputs available to system
    {M4P_SOFT_INT0_Handler              },  // 158  M4P Software Interrupt 0
    {M4P_SOFT_INT1_Handler              },  // 159  M4P Software Interrupt 1
    {M4P_SOFT_INT2_Handler              },  // 160  M4P Software Interrupt 2
    {M4P_SOFT_INT3_Handler              },  // 161  M4P Software Interrupt 3
    {M4P_SOFT_INT4_Handler              },  // 162  M4P Software Interrupt 4
    {M4P_SOFT_INT5_Handler              },  // 163  M4P Software Interrupt 5
};


#ifndef DO_NOT_RELOCATE_IVT
/*
    A relocated IVT is requested.  Provision for IVT relocation
    to RAM during startup.  This allows for dynamic interrupt
    vector patching required by RTOS.  Places the relocated IVT
    at the start of RAM.  Note: the IVT placement is required
    to be next power-of-two of the vector table size.  Since the
    IVT includes 163 programmable interrupts, 15 system exception
    vectors plus the initial stack pointer, we require
    (164 + 15 + 1)*4 = 720 bytes to move the IVT, which rounds up
    to a next-power-of-two size of 1024 (0x400) address boundary.

    Choose to relocate IVT to iBank0 (1st code SRAM bank) because
    that is the most commonly avialable bank of the various SRAM
    configurations.  iBank0 starts at address 0x10000000,
    which satisies the IVT 1024 alignment requirement.

    Also note use of the "__no_init" attibute to force the
    relocated IVT into the ".noinit" section.  This prevents
    the CRTL startup sequence from initializing the relocated
    IVT after we have activated it during the reset vector.
    so that the CRTL does not clear it.
*/
#define RELOCATION_ADDRESS   (0X10000000)  /* start of iBank0 */
#define RELOCATION_ALIGNMENT      (0x400)
#define SIZEOF_IVT sizeof(__vector_table)
#if defined ( __ICCARM__ )
    #pragma data_alignment=RELOCATION_ALIGNMENT  /* IAR */
#elif defined (__CC_ARM)
    __align(RELOCATION_ALIGNMENT)                /* Keil */
#else
    #pragma message("WARNING: NO ALIGHMENT DEFINED FOR IVT RELOCATION")
#endif
/* reserve no-init aligned IVT space at top of RAM */
SECTION_PLACE(KEEP_VAR(__no_init IntVector __relocated_vector_table[SIZEOF_IVT/4]), RELOCATION_ADDRESS);

#endif //DO_NOT_RELOCATE_IVT


#ifdef __ARMCC_VERSION
// We want a warning if semi-hosting libraries are used.
#pragma import(__use_no_semihosting_swi)
#endif

//*****************************************************************************
//
// Application Entry point
//
//*****************************************************************************
extern int main(void);


//*****************************************************************************
// Symbols defined by the GNU linker.
//*****************************************************************************
#ifdef __GNUC__
extern unsigned long _etext;
extern unsigned long _data;
extern unsigned long _edata;
extern unsigned long _bss ;
extern unsigned long _ebss;
#endif

//*****************************************************************************
// IAR system startup functions.
//*****************************************************************************
#ifdef __ICCARM__
WEAK_PROTO( void __iar_init_core (void));
WEAK_PROTO( void __iar_init_vfp  (void));
extern      void __cmain();
#endif

//*****************************************************************************
// Function    : ResetISR (-15)
// Description : Reset event handler
//*****************************************************************************
WEAK_FUNC( void ResetISR (void)) {

    /* Grant non-secure read and write access to shared SRAM on both cores*/
    *pREG_SMPU0_SECURECTL = ENUM_SMPU_SECURECTL_RNSEN | ENUM_SMPU_SECURECTL_WNSEN;
    *pREG_SMPU1_SECURECTL = ENUM_SMPU_SECURECTL_RNSEN | ENUM_SMPU_SECURECTL_WNSEN;

    /* the pre-boot kernel used the CRC unit to validate the Boot ROM    */
    /* before running it at reset, so reset/disable CRC unit at this time */
    *pREG_CRC0_CTL = REG_CRC0_CTL_RESET;

    /* reset the main SP to clean up any leftovers from the boot rom. */
    __set_MSP( (uint32_t) __vector_table[0].__ptr );


    /*
        Note: the BOOT-ROM IVT is still active at this time, which sets
        the fault pin on any non-maskable exceptions.  After 1) the default
        IVT is copied to SRAM (below) and, 2) the interrupt handlers are
        copied (by the CRTL), we change the Interrupt Vector Table Offset
        Register (VTOR) in main as part of SystemInit().  Until this sequence
        is complete, the BOOT-ROM IVT remains active.
    */


#ifndef DO_NOT_RELOCATE_IVT
    int i;
    uint8_t *pSrc, *pDst;

    /* copy the IVT (avoid use of memcpy here so it does not become locked into flash) */
    for (i=0, pSrc=(uint8_t*)__vector_table, pDst=(uint8_t*)__relocated_vector_table; i<SIZEOF_IVT; i++)
        *pDst++ = *pSrc++;

#endif //DO_NOT_RELOCATE_IVT

#ifdef __GNUC__

  unsigned long *pulSrc, *pulDest;

    // Copy initialised data from flash into RAM
    pulSrc = &_etext;
    for(pulDest = &_data; pulDest < &_edata; )
    {
        *pulDest++ = *pulSrc++;
    }

    // Clear the bss segment
    for(pulDest = &_bss; pulDest < &_ebss; )
    {
        *pulDest++ = 0;
    }
    // Call application main directly.
    main();

#elif __ICCARM__

    // Call IAR system startup
    __iar_init_core();
    __iar_init_vfp();
    __cmain();

#else

    // Call application main directly.
    main();

#endif

    // Stick here if main returns
    while(1);
}


//*****************************************************************************
// Provide default (weakly bound) trapping handlers to be overridden as needed
//*****************************************************************************
WEAK_FUNCTION( NmiSR                              )
WEAK_FUNCTION( HardFault_Handler                  )
WEAK_FUNCTION( MemManage_Handler                  )
WEAK_FUNCTION( BusFault_Handler                   )
WEAK_FUNCTION( UsageFault_Handler                 )
WEAK_FUNCTION( SVC_Handler                        )
WEAK_FUNCTION( DebugMon_Handler                   )
WEAK_FUNCTION( PendSV_Handler                     )
WEAK_FUNCTION( SysTick_Handler                    )

WEAK_FUNCTION( VMU0_VDDINT_EVT_Handler            )
WEAK_FUNCTION( VMU0_VDDEXT_EVT_Handler            )
WEAK_FUNCTION( CGU0_ERR_Handler                   )
WEAK_FUNCTION( CGU0_OSCW_INT_Handler              )
WEAK_FUNCTION( OCU0_ERR_Handler                   )
WEAK_FUNCTION( M4P_BCODE_ERR_Handler              )
WEAK_FUNCTION( CTI0_EVT0_Handler                  )
WEAK_FUNCTION( CTI0_EVT1_Handler                  )
WEAK_FUNCTION( CTI0_EVT2_Handler                  )
WEAK_FUNCTION( M4P_LOCKUP_Handler                 )
WEAK_FUNCTION( M4P_BUS_FAULT_Handler              )
WEAK_FUNCTION( M0P_LOCKUP_Handler                 )
WEAK_FUNCTION( SPU1_TIMEOUT_Handler               )
WEAK_FUNCTION( C1_BUS_TIMEOUT_Handler             )
WEAK_FUNCTION( M4P_CORE_SRAM_EERR_Handler         )
WEAK_FUNCTION( M4P_DMA_SRAM_EERR_Handler          )
WEAK_FUNCTION( FLC0_CORE_FLASH_EERR_Handler       )
WEAK_FUNCTION( FLC0_DMA_FLASH_EERR_Handler        )
WEAK_FUNCTION( FLC0_FLASH_EVT_Handler             )
WEAK_FUNCTION( M0P_SRAM_EERR_Handler              )
WEAK_FUNCTION( MBOX0_PORT1_EERR_Handler           )
WEAK_FUNCTION( MBOX0_PORT0_EERR_Handler           )
WEAK_FUNCTION( FFTB0_SPERR_Handler                )
WEAK_FUNCTION( FFTB0_DPERR_Handler                )
WEAK_FUNCTION( HAE0_PERR_Handler                  )
WEAK_FUNCTION( CSTF0_PERR_Handler                 )
WEAK_FUNCTION( SPU0_TIMEOUT_Handler               )
WEAK_FUNCTION( C0_BUS_TIMEOUT_Handler             )
WEAK_FUNCTION( C0_POSTWR_ERR_Handler              )
WEAK_FUNCTION( CGU0_EVT_Handler                   )
WEAK_FUNCTION( DPM0_EVT_Handler                   )
WEAK_FUNCTION( SEC1_ERR_Handler                   )
WEAK_FUNCTION( SEC0_ERR_Handler                   )
WEAK_FUNCTION( WDOG1_EXP_Handler                  )
WEAK_FUNCTION( WDOG0_EXP_Handler                  )
WEAK_FUNCTION( TAPC_KEYFAIL_Handler               )
WEAK_FUNCTION( AFE_NOTOK_Handler                  )
WEAK_FUNCTION( AFE_LIMIT_Handler                  )
WEAK_FUNCTION( PWM0_TRIP_Handler                  )
WEAK_FUNCTION( PWM1_TRIP_Handler                  )
WEAK_FUNCTION( PWM2_TRIP_Handler                  )
WEAK_FUNCTION( SMPU1_ERR_Handler                  )
WEAK_FUNCTION( SMPU2_ERR_Handler                  )
WEAK_FUNCTION( SMPU0_ERR_Handler                  )
WEAK_FUNCTION( SPU1_INT_Handler                   )
WEAK_FUNCTION( SPU0_INT_Handler                   )
WEAK_FUNCTION( SWU2_EVT_Handler                   )
WEAK_FUNCTION( SWU3_EVT_Handler                   )
WEAK_FUNCTION( SWU4_EVT_Handler                   )
WEAK_FUNCTION( SWU5_EVT_Handler                   )
WEAK_FUNCTION( SWU6_EVT_Handler                   )
WEAK_FUNCTION( SWU0_EVT_Handler                   )
WEAK_FUNCTION( SWU1_EVT_Handler                   )
WEAK_FUNCTION( CPTMR0_CPT0_ERR_Handler            )
WEAK_FUNCTION( CPTMR0_CPT1_ERR_Handler            )
WEAK_FUNCTION( CPTMR0_CPT2_ERR_Handler            )
WEAK_FUNCTION( CRC0_ERR_Handler                   )
WEAK_FUNCTION( SPI1_ERR_Handler                   )
WEAK_FUNCTION( SPI0_ERR_Handler                   )
WEAK_FUNCTION( FFTB0_LIMERR_Handler               )
WEAK_FUNCTION( MATH0_MSTAT_Handler                )
WEAK_FUNCTION( ADCC1_ERR_Handler                  )
WEAK_FUNCTION( DACC0_ERR_Handler                  )
WEAK_FUNCTION( ADCC0_ERR_Handler                  )
WEAK_FUNCTION( DMA4_ERR_Handler                   )
WEAK_FUNCTION( DMA5_ERR_Handler                   )
WEAK_FUNCTION( DMA6_ERR_Handler                   )
WEAK_FUNCTION( DMA7_ERR_Handler                   )
WEAK_FUNCTION( DMA8_ERR_Handler                   )
WEAK_FUNCTION( DMA9_ERR_Handler                   )
WEAK_FUNCTION( DMA10_ERR_Handler                  )
WEAK_FUNCTION( DMA11_ERR_Handler                  )
WEAK_FUNCTION( DMA12_ERR_Handler                  )
WEAK_FUNCTION( DMA13_ERR_Handler                  )
WEAK_FUNCTION( DMA0_ERR_Handler                   )
WEAK_FUNCTION( DMA1_ERR_Handler                   )
WEAK_FUNCTION( DMA2_ERR_Handler                   )
WEAK_FUNCTION( DMA3_ERR_Handler                   )
WEAK_FUNCTION( PWM0_SYNC_Handler                  )
WEAK_FUNCTION( PWM1_SYNC_Handler                  )
WEAK_FUNCTION( PWM2_SYNC_Handler                  )
WEAK_FUNCTION( PINT1_BLOCK_Handler                )
WEAK_FUNCTION( PINT2_BLOCK_Handler                )
WEAK_FUNCTION( PINT3_BLOCK_Handler                )
WEAK_FUNCTION( PINT4_BLOCK_Handler                )
WEAK_FUNCTION( PINT5_BLOCK_Handler                )
WEAK_FUNCTION( PINT0_BLOCK_Handler                )
WEAK_FUNCTION( TIMER1_TMR0_Handler                )
WEAK_FUNCTION( TIMER1_TMR1_Handler                )
WEAK_FUNCTION( TIMER1_TMR2_Handler                )
WEAK_FUNCTION( TIMER1_TMR3_Handler                )
WEAK_FUNCTION( TIMER1_TMR4_Handler                )
WEAK_FUNCTION( TIMER1_TMR5_Handler                )
WEAK_FUNCTION( TIMER1_TMR6_Handler                )
WEAK_FUNCTION( TIMER1_TMR7_Handler                )
WEAK_FUNCTION( TIMER0_TMR0_Handler                )
WEAK_FUNCTION( TIMER0_TMR1_Handler                )
WEAK_FUNCTION( TIMER0_TMR2_Handler                )
WEAK_FUNCTION( TIMER0_TMR3_Handler                )
WEAK_FUNCTION( TIMER0_TMR4_Handler                )
WEAK_FUNCTION( TIMER0_TMR5_Handler                )
WEAK_FUNCTION( TIMER0_TMR6_Handler                )
WEAK_FUNCTION( TIMER0_TMR7_Handler                )
WEAK_FUNCTION( TIMER1_STAT_Handler                )
WEAK_FUNCTION( TIMER0_STAT_Handler                )
WEAK_FUNCTION( CPTMR0_CPT0_MEAS_Handler           )
WEAK_FUNCTION( CPTMR0_CPT1_MEAS_Handler           )
WEAK_FUNCTION( CPTMR0_CPT2_MEAS_Handler           )
WEAK_FUNCTION( DMA4_INT_Handler                   )
WEAK_FUNCTION( DMA5_INT_Handler                   )
WEAK_FUNCTION( DMA6_INT_Handler                   )
WEAK_FUNCTION( DMA7_INT_Handler                   )
WEAK_FUNCTION( DMA8_INT_Handler                   )
WEAK_FUNCTION( DMA9_INT_Handler                   )
WEAK_FUNCTION( DMA10_INT_Handler                  )
WEAK_FUNCTION( DMA11_INT_Handler                  )
WEAK_FUNCTION( DMA12_INT_Handler                  )
WEAK_FUNCTION( DMA13_INT_Handler                  )
WEAK_FUNCTION( DMA0_INT_Handler                   )
WEAK_FUNCTION( DMA1_INT_Handler                   )
WEAK_FUNCTION( DMA2_INT_Handler                   )
WEAK_FUNCTION( DMA3_INT_Handler                   )
WEAK_FUNCTION( TRU1_INT0_Handler                  )
WEAK_FUNCTION( TRU1_INT1_Handler                  )
WEAK_FUNCTION( TRU1_INT2_Handler                  )
WEAK_FUNCTION( TRU1_INT3_Handler                  )
WEAK_FUNCTION( TRU0_INT0_Handler                  )
WEAK_FUNCTION( FFTB0_DONE_Handler                 )
WEAK_FUNCTION( ADCC1_TMR0_EVT_Handler             )
WEAK_FUNCTION( ADCC1_TMR1_EVT_Handler             )
WEAK_FUNCTION( ADCC0_TMR0_EVT_Handler             )
WEAK_FUNCTION( ADCC0_TMR1_EVT_Handler             )
WEAK_FUNCTION( DACC0_DAC0_Handler                 )
WEAK_FUNCTION( DACC0_DAC1_Handler                 )
WEAK_FUNCTION( SPI1_STAT_Handler                  )
WEAK_FUNCTION( SPI0_STAT_Handler                  )
WEAK_FUNCTION( SPORT0_A_STAT_Handler              )
WEAK_FUNCTION( SPORT0_B_STAT_Handler              )
WEAK_FUNCTION( UART1_STAT_Handler                 )
WEAK_FUNCTION( UART2_STAT_Handler                 )
WEAK_FUNCTION( UART3_STAT_Handler                 )
WEAK_FUNCTION( UART4_STAT_Handler                 )
WEAK_FUNCTION( UART0_STAT_Handler                 )
WEAK_FUNCTION( HAE0_STAT_Handler                  )
WEAK_FUNCTION( CRC0_DCNTEXP_Handler               )
WEAK_FUNCTION( CAN1_TX_Handler                    )
WEAK_FUNCTION( CAN1_RX_Handler                    )
WEAK_FUNCTION( CAN1_STAT_Handler                  )
WEAK_FUNCTION( CAN0_TX_Handler                    )
WEAK_FUNCTION( CAN0_RX_Handler                    )
WEAK_FUNCTION( CAN0_STAT_Handler                  )
WEAK_FUNCTION( CNT0_STAT_Handler                  )
WEAK_FUNCTION( SINC0_STAT_Handler                 )
WEAK_FUNCTION( TWI0_DATA_Handler                  )
WEAK_FUNCTION( MBOX0_PORT1_MSG_Handler            )
WEAK_FUNCTION( MBOX0_PORT0_MSG_Handler            )
WEAK_FUNCTION( LBA0_SYS_OUT0_Handler              )
WEAK_FUNCTION( M4P_SOFT_INT0_Handler              )
WEAK_FUNCTION( M4P_SOFT_INT1_Handler              )
WEAK_FUNCTION( M4P_SOFT_INT2_Handler              )
WEAK_FUNCTION( M4P_SOFT_INT3_Handler              )
WEAK_FUNCTION( M4P_SOFT_INT4_Handler              )
WEAK_FUNCTION( M4P_SOFT_INT5_Handler              )
WEAK_FUNCTION( RESERVED_VECTOR                    )
